@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #           Nobuhiro Iwamatsu <iwamatsu@nigauri.org>                            #
@@ -25,7 +25,7 @@
 /* support for internationalization - i18n */
 #include <glib/gi18n.h>
 #include <glib.h>
-#include <glib/gprintf.h>
+#include <pthread.h>
 #include <gdk/gdkkeysyms.h>
 
 #include <portaudio.h>
@@ -48,6 +48,10 @@
 #include "create_video.h"
 #include "video_format.h"
 
+#define __AMUTEX &pdata->mutex
+#define __VMUTEX &videoIn->mutex
+#define __GMUTEX &global->mutex
+
 /*--------------------------- warning message dialog ----------------------------*/
 void
 WARN_DIALOG(const char *warn_title, const char* warn_msg, struct ALL_DATA *all_data)
@@ -57,7 +61,7 @@ WARN_DIALOG(const char *warn_title, const char* warn_msg, struct ALL_DATA *all_d
 	
     if(global->no_display)
     {
-        g_printf("WARNING: %s\n", warn_msg);
+        g_print("WARNING: %s\n", warn_msg);
     }
     else
     {
@@ -108,20 +112,18 @@ ERR_DIALOG(const char *err_title, const char* err_msg, struct ALL_DATA *all_data
                 GTK_RESPONSE_REJECT,
                 NULL);
             
-            GtkWidget *table = gtk_table_new(4,2,FALSE);
+            GtkWidget *table = gtk_grid_new();
             
             GtkWidget *title = gtk_label_new (gettext(err_title));
             gtk_widget_modify_font(title, pango_font_description_from_string ("Sans bold 10"));
             gtk_misc_set_alignment (GTK_MISC (title), 0, 0);
-            gtk_table_attach (GTK_TABLE (table), title, 0, 2, 0, 1,
-                        GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0, 0);
+            gtk_grid_attach (GTK_GRID (table), title, 0, 0, 2, 1);
             gtk_widget_show (title);
             
             GtkWidget *text = gtk_label_new (gettext(err_msg));
             gtk_widget_modify_font(text, pango_font_description_from_string ("Sans italic 8"));
             gtk_misc_set_alignment (GTK_MISC (text), 0, 0);
-            gtk_table_attach (GTK_TABLE (table), text, 0, 2, 1, 2,
-                        GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0, 0);
+            gtk_grid_attach (GTK_GRID (table), text, 0, 1, 2, 1);
             gtk_widget_show (text);
 
 
@@ -129,27 +131,24 @@ ERR_DIALOG(const char *err_title, const char* err_msg, struct ALL_DATA *all_data
                 "Do you want to try another one ?\n"));
             gtk_widget_modify_font(text2, pango_font_description_from_string ("Sans 10"));
             gtk_misc_set_alignment (GTK_MISC (text2), 0, 0);
-            gtk_table_attach (GTK_TABLE (table), text2, 0, 2, 2, 3,
-                        GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0, 0);
+            gtk_grid_attach (GTK_GRID (table), text2, 0, 2, 2, 1);
             gtk_widget_show (text2);
             
             GtkWidget *lbl_dev = gtk_label_new(_("Device:"));
             gtk_misc_set_alignment (GTK_MISC (lbl_dev), 0.5, 0.5);
-            gtk_table_attach (GTK_TABLE(table), lbl_dev, 0, 1, 3, 4,
-                GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0, 0);
+            gtk_grid_attach (GTK_GRID(table), lbl_dev, 0, 3, 1, 1);
             gtk_widget_show (lbl_dev);
             
-            Devices = gtk_combo_box_new_text ();
+            Devices = gtk_combo_box_text_new ();
             
             for(i=0;i<(videoIn->listDevices->num_devices);i++)
             {
-                gtk_combo_box_append_text(GTK_COMBO_BOX(Devices),
+                gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Devices),
                     videoIn->listDevices->listVidDevices[i].name);
             }
             gtk_combo_box_set_active(GTK_COMBO_BOX(Devices),videoIn->listDevices->num_devices-1);
             
-            gtk_table_attach(GTK_TABLE(table), Devices, 1, 2, 3, 4,
-                GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0, 0);
+            gtk_grid_attach(GTK_GRID(table), Devices, 1, 3, 1, 1);
             gtk_widget_show (Devices);
 
             GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (errdialog));
@@ -215,14 +214,14 @@ ERR_DIALOG(const char *err_title, const char* err_msg, struct ALL_DATA *all_data
 	/* but this means we must close portaudio before exiting        */
 	if(!control_only)
 	{
-		g_printf("Closing portaudio ...");
+		g_print("Closing portaudio ...");
 		if (Pa_Terminate() != paNoError) 
-			g_printf("Error\n");
+			g_print("Error\n");
 		else
-			g_printf("OK\n");
+			g_print("OK\n");
 	}
 	
-	g_printf("Terminated.\n");;
+	g_print("Terminated.\n");;
 	exit(1);
 };
 
@@ -247,6 +246,8 @@ set_sensitive_img_contrls (const int flag, struct GWIDGET *gwidget)
 	gtk_widget_set_sensitive(gwidget->ImageType, flag);/*file type combo*/
 	gtk_widget_set_sensitive(gwidget->ImageFNameEntry, flag);/*Image Entry*/
 	gtk_widget_set_sensitive(gwidget->ImageInc, flag);/*image inc checkbox*/
+	gtk_widget_set_sensitive(gwidget->TakeImageByDefault, flag);/*default action radio*/
+	gtk_widget_set_sensitive(gwidget->TakeVidByDefault, flag);/*default action radio*/
 }
 
 /* sound controls*/
@@ -257,6 +258,8 @@ set_sensitive_snd_contrls (const int flag, struct GWIDGET *gwidget)
 	gtk_widget_set_sensitive (gwidget->SndDevice, flag);
 	gtk_widget_set_sensitive (gwidget->SndNumChan, flag);
 	gtk_widget_set_sensitive (gwidget->SndComp, flag);
+	gtk_widget_set_sensitive(gwidget->TakeImageByDefault, flag);/*default action radio*/
+	gtk_widget_set_sensitive(gwidget->TakeVidByDefault, flag);/*default action radio*/
 }
 
 /*video controls*/
@@ -307,26 +310,26 @@ key_pressed (GtkWidget *win, GdkEventKey *event, struct ALL_DATA *all_data)
     {
         switch (event->keyval)
         {
-            case GDK_Down:
-            case GDK_KP_Down:
+            case GDK_KEY_Down:
+            case GDK_KEY_KP_Down:
                 /*Tilt Down*/
                 uvcPanTilt (videoIn->fd, s->control_list, 0, 1);
                 return TRUE;
                 
-            case GDK_Up:
-            case GDK_KP_Up:
+            case GDK_KEY_Up:
+            case GDK_KEY_KP_Up:
                 /*Tilt UP*/
                 uvcPanTilt (videoIn->fd, s->control_list, 0, -1);
                 return TRUE;
                 
-            case GDK_Left:
-            case GDK_KP_Left:
+            case GDK_KEY_Left:
+            case GDK_KEY_KP_Left:
                 /*Pan Left*/
                 uvcPanTilt (videoIn->fd, s->control_list, 1, 1);
                 return TRUE;
                 
-            case GDK_Right:
-            case GDK_KP_Right:
+            case GDK_KEY_Right:
+            case GDK_KEY_KP_Right:
                 /*Pan Right*/
                 uvcPanTilt (videoIn->fd, s->control_list, 1, -1);
                 return TRUE;
@@ -338,10 +341,14 @@ key_pressed (GtkWidget *win, GdkEventKey *event, struct ALL_DATA *all_data)
     
     switch (event->keyval)
     {
-        case GDK_WebCam:
+        case GDK_KEY_WebCam:
 
         /* camera button pressed - trigger image capture*/
-        gtk_button_clicked (GTK_BUTTON(gwidget->CapImageButt));
+        if (all_data->global->default_action == 0) {
+        	gtk_button_clicked (GTK_BUTTON(gwidget->CapImageButt));
+        } else {
+        	gtk_toggle_button_toggled (GTK_TOGGLE_BUTTON(gwidget->CapVidButt));
+        }
         return TRUE;
     }
 
@@ -355,7 +362,7 @@ void
 slider_changed (GtkRange * range, struct ALL_DATA *all_data)
 {
     struct VidState *s = all_data->s;
-    struct GLOBAL *global = all_data->global;
+    //struct GLOBAL *global = all_data->global;
     struct vdIn *videoIn = all_data->videoIn;
 
     int id = GPOINTER_TO_INT(g_object_get_data (G_OBJECT (range), "control_info"));
@@ -380,7 +387,7 @@ slider_changed (GtkRange * range, struct ALL_DATA *all_data)
     }
 	
 	s = NULL;
-	global = NULL;
+	//global = NULL;
 	videoIn = NULL;
 }
 
@@ -389,7 +396,7 @@ void
 spin_changed (GtkSpinButton * spin, struct ALL_DATA *all_data)
 {
 	struct VidState *s = all_data->s;
-	struct GLOBAL *global = all_data->global;
+	//struct GLOBAL *global = all_data->global;
 	struct vdIn *videoIn = all_data->videoIn;
 	
 	int id = GPOINTER_TO_INT(g_object_get_data (G_OBJECT (spin), "control_info"));
@@ -412,7 +419,7 @@ spin_changed (GtkSpinButton * spin, struct ALL_DATA *all_data)
     }
 
 	s = NULL;
-	global = NULL;
+	//global = NULL;
 	videoIn = NULL;
 }
 
@@ -472,7 +479,7 @@ void
 check_changed (GtkToggleButton * toggle, struct ALL_DATA *all_data)
 {
     struct VidState *s = all_data->s;
-    struct GLOBAL *global = all_data->global;
+   //struct GLOBAL *global = all_data->global;
     struct vdIn *videoIn = all_data->videoIn;
 
     int id = GPOINTER_TO_INT(g_object_get_data (G_OBJECT (toggle), "control_info"));
@@ -494,7 +501,7 @@ check_changed (GtkToggleButton * toggle, struct ALL_DATA *all_data)
     }
     
     s = NULL;
-    global = NULL;
+    //global = NULL;
     videoIn = NULL;
 }
 
@@ -659,9 +666,10 @@ Devices_changed (GtkComboBox * Devices, struct ALL_DATA *all_data)
 		GTK_RESPONSE_CANCEL,
 		NULL);
 	
+	GtkWidget * content_area = gtk_dialog_get_content_area (GTK_DIALOG (gwidget->restartdialog));
 	GtkWidget *message = gtk_label_new (_("launch new process or restart?.\n\n"));
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(gwidget->restartdialog)->vbox), message);
-	gtk_widget_show_all(GTK_WIDGET(GTK_CONTAINER (GTK_DIALOG(gwidget->restartdialog)->vbox)));
+	gtk_container_add (GTK_CONTAINER (content_area), message);
+	gtk_widget_show_all(gwidget->restartdialog);
 	
 	gint result = gtk_dialog_run (GTK_DIALOG (gwidget->restartdialog));
 	switch (result) 
@@ -702,13 +710,13 @@ resolution_changed (GtkComboBox * Resolution, struct ALL_DATA *all_data)
 	int cmb_index = gtk_combo_box_get_active(Resolution);
 	char temp_str[20];
 	
-	g_mutex_lock(videoIn->mutex);
+	__LOCK_MUTEX(__VMUTEX);
 		gboolean capVid = videoIn->capVid;
-	g_mutex_unlock(videoIn->mutex);
+	__UNLOCK_MUTEX(__VMUTEX);
 	/*disable fps combobox signals*/
-	g_signal_handlers_block_by_func(GTK_COMBO_BOX(gwidget->FrameRate), G_CALLBACK (FrameRate_changed), all_data);
+	g_signal_handlers_block_by_func(GTK_COMBO_BOX_TEXT(gwidget->FrameRate), G_CALLBACK (FrameRate_changed), all_data);
 	/* clear out the old fps list... */
-	GtkListStore *store = GTK_LIST_STORE(gtk_combo_box_get_model (GTK_COMBO_BOX (gwidget->FrameRate)));
+	GtkListStore *store = GTK_LIST_STORE(gtk_combo_box_get_model (GTK_COMBO_BOX(gwidget->FrameRate)));
 	gtk_list_store_clear(store);
 
 
@@ -724,7 +732,7 @@ resolution_changed (GtkComboBox * Resolution, struct ALL_DATA *all_data)
 	{
 		g_snprintf(temp_str,18,"%i/%i fps", listVidCap->framerate_denom[i],
 			listVidCap->framerate_num[i]);
-		gtk_combo_box_append_text(GTK_COMBO_BOX(gwidget->FrameRate),temp_str);
+		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gwidget->FrameRate),temp_str);
 		
 		if (( global->fps_num == listVidCap->framerate_num[i]) && 
 			(global->fps == listVidCap->framerate_denom[i]))
@@ -735,7 +743,7 @@ resolution_changed (GtkComboBox * Resolution, struct ALL_DATA *all_data)
 	gtk_combo_box_set_active(GTK_COMBO_BOX(gwidget->FrameRate),deffps);
 	
 	/*enable fps combobox signals*/ 
-	g_signal_handlers_unblock_by_func(GTK_COMBO_BOX(gwidget->FrameRate), G_CALLBACK (FrameRate_changed), all_data);
+	g_signal_handlers_unblock_by_func(GTK_COMBO_BOX_TEXT(gwidget->FrameRate), G_CALLBACK (FrameRate_changed), all_data);
 	
 	if (listVidCap->framerate_num)	
 		global->fps_num = listVidCap->framerate_num[deffps];
@@ -773,10 +781,10 @@ InpType_changed(GtkComboBox * InpType, struct ALL_DATA *all_data)
 	VidFormats *listVidFormats;
 	
 	/*disable resolution combobox signals*/
-	g_signal_handlers_block_by_func(GTK_COMBO_BOX(gwidget->Resolution), G_CALLBACK (resolution_changed), all_data);
+	g_signal_handlers_block_by_func(GTK_COMBO_BOX_TEXT(gwidget->Resolution), G_CALLBACK (resolution_changed), all_data);
 	
 	/* clear out the old resolution list... */
-	GtkListStore *store = GTK_LIST_STORE(gtk_combo_box_get_model (GTK_COMBO_BOX (gwidget->Resolution)));
+	GtkListStore *store = GTK_LIST_STORE(gtk_combo_box_get_model (GTK_COMBO_BOX(gwidget->Resolution)));
 	gtk_list_store_clear(store);
 	
 	videoIn->listFormats->current_format = index;
@@ -792,7 +800,7 @@ InpType_changed(GtkComboBox * InpType, struct ALL_DATA *all_data)
 		{
 			g_snprintf(temp_str,18,"%ix%i", listVidFormats->listVidCap[i].width,
 							 listVidFormats->listVidCap[i].height);
-			gtk_combo_box_append_text(GTK_COMBO_BOX(gwidget->Resolution),temp_str);
+			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gwidget->Resolution),temp_str);
 			
 			if ((global->width == listVidFormats->listVidCap[i].width) && 
 				(global->height == listVidFormats->listVidCap[i].height))
@@ -806,7 +814,7 @@ InpType_changed(GtkComboBox * InpType, struct ALL_DATA *all_data)
 	global->format = format;
 	
 	/*enable resolution combobox signals*/
-	g_signal_handlers_unblock_by_func(GTK_COMBO_BOX(gwidget->Resolution), G_CALLBACK (resolution_changed), all_data);
+	g_signal_handlers_unblock_by_func(GTK_COMBO_BOX_TEXT(gwidget->Resolution), G_CALLBACK (resolution_changed), all_data);
 	
 	/*reset resolution/format*/
 	gtk_combo_box_set_active(GTK_COMBO_BOX(gwidget->Resolution),defres);
@@ -902,7 +910,7 @@ SndAPI_changed (GtkComboBox * SoundAPI, struct ALL_DATA *all_data)
 		gtk_combo_box_set_active(GTK_COMBO_BOX(gwidget->SndDevice),global->Sound_UseDev);
 		gtk_widget_set_sensitive (gwidget->SndDevice, FALSE); //disable sound device combobox
 	}
-	g_printf("using audio API n:%d\n",global->Sound_API);
+	g_print("using audio API n:%d\n",global->Sound_API);
 	global = NULL;
 }
 
@@ -913,7 +921,7 @@ SndDevice_changed (GtkComboBox * SoundDevice, struct ALL_DATA *all_data)
 	struct GLOBAL *global = all_data->global;
 	
 	global->Sound_UseDev=gtk_combo_box_get_active (SoundDevice);
-	g_printf("using device id:%d\n",global->Sound_IndexDev[global->Sound_UseDev].id);
+	g_print("using device id:%d\n",global->Sound_IndexDev[global->Sound_UseDev].id);
 	global = NULL;
 }
 
@@ -968,12 +976,12 @@ SndEnable_changed (GtkToggleButton * toggle, struct ALL_DATA *all_data)
 	global->Sound_enable = gtk_toggle_button_get_active (toggle) ? 1 : 0;
 	if (!global->Sound_enable) 
 	{
-		if(global->debug) g_printf("disabling sound.\n");
+		if(global->debug) g_print("disabling sound.\n");
 		set_sensitive_snd_contrls(FALSE, gwidget);
 	}
 	else 
 	{ 
-		if(global->debug) g_printf("enabling sound.\n");
+		if(global->debug) g_print("enabling sound.\n");
 		set_sensitive_snd_contrls(TRUE, gwidget);
 	}
 	
@@ -987,11 +995,11 @@ FiltEnable_changed(GtkToggleButton * toggle, struct ALL_DATA *all_data)
 {
 	struct GLOBAL *global = all_data->global;
 	int filter = GPOINTER_TO_INT(g_object_get_data (G_OBJECT (toggle), "filt_info"));
-	g_mutex_lock(global->mutex);
+	__LOCK_MUTEX(__GMUTEX);
 		global->Frame_Flags = gtk_toggle_button_get_active (toggle) ? 
 			(global->Frame_Flags | filter) : 
 			(global->Frame_Flags & ~(filter));
-	g_mutex_unlock(global->mutex);
+	__UNLOCK_MUTEX(__GMUTEX);
 	
 	global = NULL;
 }
@@ -1002,11 +1010,11 @@ EffEnable_changed(GtkToggleButton * toggle, struct ALL_DATA *all_data)
 {
 	struct paRecordData *pdata = all_data->pdata;
 	int effect = GPOINTER_TO_INT(g_object_get_data (G_OBJECT (toggle), "effect_info"));
-	g_mutex_lock(pdata->mutex);
+	__LOCK_MUTEX(__AMUTEX);
 		pdata->snd_Flags = gtk_toggle_button_get_active (toggle) ? 
 			(pdata->snd_Flags | effect) : 
 			(pdata->snd_Flags & ~(effect));
-	g_mutex_unlock(pdata->mutex);
+	__UNLOCK_MUTEX(__AMUTEX);
 	pdata = NULL;
 }
 
@@ -1130,10 +1138,10 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data)
 	struct GLOBAL *global = all_data->global;
 	struct vdIn *videoIn = all_data->videoIn;
 
-	g_mutex_lock(videoIn->mutex);
+	__LOCK_MUTEX(__VMUTEX);
 		gboolean capVid = videoIn->capVid;
-	g_mutex_unlock(videoIn->mutex);
-    const char *fileEntr;
+	__UNLOCK_MUTEX(__VMUTEX);
+    char *fileEntr = NULL;
     gboolean state=!capVid;
     
     if(!global->no_display)
@@ -1142,12 +1150,12 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data)
         g_signal_handlers_block_by_func(GTK_TOGGLE_BUTTON(gwidget->CapVidButt), G_CALLBACK (capture_vid), all_data);
         /*widgets are enable/disable in create_video.c*/
         
-        fileEntr = gtk_entry_get_text(GTK_ENTRY(gwidget->VidFNameEntry));
+        fileEntr = (char *) gtk_entry_get_text(GTK_ENTRY(gwidget->VidFNameEntry));
         if(g_strcmp0(fileEntr,global->vidFPath[0])!=0) 
         {
             /*reset if entry change from last capture*/
             if(global->vid_inc) global->vid_inc=1;
-            global->vidFPath=splitPath((char *)fileEntr, global->vidFPath);
+            global->vidFPath=splitPath(fileEntr, global->vidFPath);
             gtk_entry_set_text(GTK_ENTRY(gwidget->VidFNameEntry),"");
             gtk_entry_set_text(GTK_ENTRY(gwidget->VidFNameEntry),global->vidFPath[0]);
             /*get the file type*/
@@ -1156,33 +1164,34 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data)
             gtk_combo_box_set_active(GTK_COMBO_BOX(gwidget->VidFormat),global->VidFormat);
         }
         //check button state
-        state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt));
+        //state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt));
     }
    
-	if(global->debug) g_printf("Cap Video toggled: %d\n", state);
+	if(global->debug) g_print("Cap Video toggled: %d\n", state);
 	
 	if(capVid || !state) 
 	{	/****************** Stop Video ************************/
 		capVid = FALSE;
-		g_mutex_lock(videoIn->mutex);
+		__LOCK_MUTEX(__VMUTEX);
 			videoIn->capVid = capVid;
-		g_mutex_unlock(videoIn->mutex);
-		g_mutex_lock(pdata->mutex);
+		__UNLOCK_MUTEX(__VMUTEX);
+		__LOCK_MUTEX(__AMUTEX);
 			pdata->capVid = capVid;
-		g_mutex_unlock(pdata->mutex);
+		__UNLOCK_MUTEX(__AMUTEX);
 		/*join IO thread*/
-		if (global->debug) g_printf("Shuting Down IO Thread\n");
-		g_thread_join( all_data->IO_thread );
-		if (global->debug) g_printf("IO Thread finished\n");
+		if (global->debug) g_print("Shuting Down IO Thread\n");
+		__THREAD_JOIN( all_data->IO_thread );
+		if (global->debug) g_print("IO Thread finished\n");
 
         if(!global->no_display)
         {
-            if(global->debug) g_printf("enabling controls\n");
+            if(global->debug) g_print("enabling controls\n");
             /*enabling sound and video compression controls*/
             set_sensitive_vid_contrls(TRUE, global->Sound_enable, gwidget);
             if(!(state))
             {
                 gtk_button_set_label(GTK_BUTTON(gwidget->CapVidButt),_("Cap. Video"));
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt), FALSE);
                 //gtk_widget_show (gwidget->VidButton_Img);
             }
         }
@@ -1193,7 +1202,7 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data)
 	{	/******************** Start Video *********************/
         if(!global->no_display)
         {
-            global->vidFPath=splitPath((char *)fileEntr, global->vidFPath);
+            global->vidFPath=splitPath(fileEntr, global->vidFPath);
             g_snprintf(global->vidinc_str,24,_("File num:%d"),global->vid_inc);
             gtk_label_set_text(GTK_LABEL(gwidget->VidIncLabel), global->vidinc_str);
         }
@@ -1214,7 +1223,7 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data)
 		/* check if enough free space is available on disk*/
 		if(!DiskSupervisor(all_data))
 		{
-			g_printf("Cap Video failed\n");
+			g_print("Cap Video failed\n");
 			state = FALSE;
 		}
 		else
@@ -1227,19 +1236,10 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data)
             if(!global->no_display)
                 set_sensitive_vid_contrls(FALSE, global->Sound_enable, gwidget);
 			
-			GError *err1 = NULL;
 			/*start IO thread*/
-			if( (all_data->IO_thread = g_thread_create_full((GThreadFunc) IO_loop, 
-				(void *) all_data,       //data - argument supplied to thread
-				global->stack_size,       //stack size
-				TRUE,                     //joinable
-				FALSE,                    //bound
-				G_THREAD_PRIORITY_NORMAL, //priority - no priority for threads in GNU-Linux
-				&err1)                    //error
-			) == NULL)
+			if( __THREAD_CREATE(&all_data->IO_thread, IO_loop, (void *) all_data))
 			{
-				g_printerr("Thread create failed: %s!!\n", err1->message );
-				g_error_free ( err1 ) ;
+				g_printerr("Thread creation failed\n");
 				state = FALSE;
 			}
 		}
@@ -1249,6 +1249,7 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data)
             if(state)
             {
                 gtk_button_set_label(GTK_BUTTON(gwidget->CapVidButt),_("Stop Video"));
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(gwidget->CapVidButt), TRUE);
                 //gtk_widget_show (gwidget->VidButton_Img);
             }
             else
@@ -1268,6 +1269,33 @@ capture_vid (GtkToggleButton *VidButt, struct ALL_DATA *all_data)
 	videoIn = NULL;
 }
 
+void
+TakePictureByDefault_clicked (GtkRadioButton * radio, struct ALL_DATA *all_data)
+{
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(radio))) 
+	{
+		all_data->global->default_action = 0;
+	} else 
+	{
+		all_data->global->default_action = 1;
+	}
+	return;
+}
+
+void
+TakeVidByDefault_clicked (GtkRadioButton * radio, struct ALL_DATA *all_data)
+{
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(radio))) 
+	{
+		all_data->global->default_action = 1;
+	} 
+	else 
+	{
+		all_data->global->default_action = 0;
+	}
+	return;
+}
+
 /*--------------------- buttons callbacks ------------------*/
 void
 DefaultsButton_clicked (GtkButton * DefaultsButton, struct ALL_DATA *all_data)
@@ -1282,12 +1310,12 @@ void
 ProfileButton_clicked (GtkButton * ProfileButton, struct ALL_DATA *all_data)
 {
 	struct GWIDGET *gwidget = all_data->gwidget;
-	struct VidState *s = all_data->s;
+	//struct VidState *s = all_data->s;
 	struct GLOBAL *global = all_data->global;
-	struct vdIn *videoIn = all_data->videoIn;
+	//struct vdIn *videoIn = all_data->videoIn;
 	
 	gboolean *save = g_object_get_data (G_OBJECT (ProfileButton), "profile_save");
-	if(global->debug) g_printf("Profile dialog (%d)\n",*save);
+	if(global->debug) g_print("Profile dialog (%d)\n",*save);
 	if (*save)
 	{
 		gwidget->FileDialog = gtk_file_chooser_dialog_new (_("Save File"),
@@ -1327,9 +1355,9 @@ ProfileButton_clicked (GtkButton * ProfileButton, struct ALL_DATA *all_data)
 	}
 	gtk_widget_destroy (gwidget->FileDialog);
 	gwidget = NULL;
-	s = NULL;
+	//s = NULL;
 	global = NULL;
-	videoIn = NULL;
+	//videoIn = NULL;
 }
 
 /*called when avi max file size reached*/
@@ -1361,7 +1389,7 @@ split_avi(void *data)
     gdk_threads_leave();
 
     /*FIXME: should join the caller thread instead (will it work?)*/
-    int stall = wait_ms(&(videoIn->IOfinished), TRUE, videoIn->mutex, 10, 200);
+    int stall = wait_ms(&(videoIn->IOfinished), TRUE, __VMUTEX, 10, 200);
     if( !(stall > 0) )
     {
         g_printerr("IO thread stalled (%d) - timeout\n",
