@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #                                                                               #
@@ -21,7 +21,7 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <glib/gprintf.h>
+#include <pthread.h>
 #include <stdlib.h>
 
 #include "../config.h"
@@ -40,6 +40,12 @@
 #include "audio_effects.h"
 #include "globals.h"
 
+
+#define __AMUTEX &pdata->mutex
+#define __VMUTEX &videoIn->mutex
+#define __GMUTEX &global->mutex
+#define __GCOND  &global->IO_cond
+
 /*video capture can only start after buffer allocation*/
 static void alloc_videoBuff(struct ALL_DATA *all_data)
 {
@@ -51,7 +57,7 @@ static void alloc_videoBuff(struct ALL_DATA *all_data)
 	if (global->video_buff_size < 2) global->video_buff_size = 2; /*keep at least two frames*/
 	
 	/*alloc video ring buffer*/
-	g_mutex_lock(global->mutex);
+	__LOCK_MUTEX(__GMUTEX);
 		if (global->videoBuff == NULL)
 		{
 			/*alloc video frames to videoBuff*/
@@ -81,7 +87,7 @@ static void alloc_videoBuff(struct ALL_DATA *all_data)
 		//reset indexes
 		global->r_ind=0;
 		global->w_ind=0;
-	g_mutex_unlock(global->mutex);
+	__UNLOCK_MUTEX(__GMUTEX);
 }
 
 static int initVideoFile(struct ALL_DATA *all_data, void * lavc_aud_data)
@@ -99,9 +105,9 @@ static int initVideoFile(struct ALL_DATA *all_data, void * lavc_aud_data)
 	videoF->keyframe = 0;
 	int ret = 0;
 	
-	g_mutex_lock(videoIn->mutex);
+	__LOCK_MUTEX(__VMUTEX);
 		gboolean capVid = videoIn->capVid;
-	g_mutex_unlock(videoIn->mutex);
+	__UNLOCK_MUTEX(__VMUTEX);
 	
 	/*alloc video ring buffer*/
 	alloc_videoBuff(all_data);
@@ -120,9 +126,9 @@ static int initVideoFile(struct ALL_DATA *all_data, void * lavc_aud_data)
 			{
 				g_printerr("Error: Couldn't create Video.\n");
 				capVid = FALSE; /*don't start video capture*/
-				g_mutex_lock(videoIn->mutex);
+				__LOCK_MUTEX(__VMUTEX);
 					videoIn->capVid = capVid;
-				g_mutex_unlock(videoIn->mutex);
+				__UNLOCK_MUTEX(__VMUTEX);
 				pdata->capVid = capVid;
 				return(-1);
 			} 
@@ -133,9 +139,9 @@ static int initVideoFile(struct ALL_DATA *all_data, void * lavc_aud_data)
 		  
 				/* start video capture*/
 				capVid = TRUE;
-				g_mutex_lock(videoIn->mutex);
+				__LOCK_MUTEX(__VMUTEX);
 					videoIn->capVid = capVid;
-				g_mutex_unlock(videoIn->mutex);
+				__UNLOCK_MUTEX(__VMUTEX);
 				pdata->capVid = capVid;
 				
 				/* start sound capture*/
@@ -177,9 +183,9 @@ static int initVideoFile(struct ALL_DATA *all_data, void * lavc_aud_data)
 			if(init_FormatContext((void *) all_data)<0)
 			{
 				capVid = FALSE;
-				g_mutex_lock(videoIn->mutex);
+				__LOCK_MUTEX(__VMUTEX);
 					videoIn->capVid = capVid;
-				g_mutex_unlock(videoIn->mutex);
+				__UNLOCK_MUTEX(__VMUTEX);
 				pdata->capVid = capVid;
 				return (-1);
 			}
@@ -190,9 +196,9 @@ static int initVideoFile(struct ALL_DATA *all_data, void * lavc_aud_data)
 			
 			/* start video capture*/
 			capVid = TRUE;
-			g_mutex_lock(videoIn->mutex);
+			__LOCK_MUTEX(__VMUTEX);
 				videoIn->capVid = capVid;
-			g_mutex_unlock(videoIn->mutex);
+			__UNLOCK_MUTEX(__VMUTEX);
 			pdata->capVid = capVid;
 			
 			
@@ -234,7 +240,7 @@ aviClose (struct ALL_DATA *all_data)
 	float tottime = 0;
 
 	struct GLOBAL *global = all_data->global;
-	struct vdIn *videoIn = all_data->videoIn;
+	//struct vdIn *videoIn = all_data->videoIn;
 	struct VideoFormatData *videoF = all_data->videoF;
 	struct paRecordData *pdata = all_data->pdata;
 
@@ -242,7 +248,7 @@ aviClose (struct ALL_DATA *all_data)
 	{
 		tottime = (float) ((int64_t) (global->Vidstoptime - global->Vidstarttime) / 1000000); // convert to miliseconds
 		
-		if (global->debug) g_printf("stop= %llu start=%llu \n",
+		if (global->debug) g_print("stop= %llu start=%llu \n",
 			(unsigned long long) global->Vidstoptime, (unsigned long long) global->Vidstarttime);
 		if (tottime > 0) 
 		{
@@ -255,7 +261,7 @@ aviClose (struct ALL_DATA *all_data)
 			videoF->AviOut->fps = global->fps;
 		}
 
-		if (global->debug) g_printf("VIDEO: %d frames in %f ms = %f fps\n",global->framecount,tottime,videoF->AviOut->fps);
+		if (global->debug) g_print("VIDEO: %d frames in %f ms = %f fps\n",global->framecount,tottime,videoF->AviOut->fps);
 		/*------------------- close audio stream and clean up -------------------*/
 		if (global->Sound_enable > 0) 
 		{
@@ -264,13 +270,13 @@ aviClose (struct ALL_DATA *all_data)
 		AVI_close (videoF->AviOut);
 		global->framecount = 0;
 		global->Vidstarttime = 0;
-		if (global->debug) g_printf ("close avi\n");
+		if (global->debug) g_print ("close avi\n");
 	}
 	
 	g_free(videoF->AviOut);
 	pdata = NULL;
 	global = NULL;
-	videoIn = NULL;
+	//videoIn = NULL;
 	videoF->AviOut = NULL;
 }
 
@@ -284,16 +290,16 @@ static void closeVideoFile(struct ALL_DATA *all_data)
 	int i=0;
 	/*we are streaming so we need to lock a mutex*/
 	gboolean capVid = FALSE;
-	g_mutex_lock(videoIn->mutex);
+	__LOCK_MUTEX(__VMUTEX);
 		videoIn->capVid = capVid; /*flag video thread to stop recording frames*/
-	g_mutex_unlock(videoIn->mutex);
-	g_mutex_lock(pdata->mutex);
+	__UNLOCK_MUTEX(__VMUTEX);
+	__LOCK_MUTEX(__AMUTEX);
 		pdata->capVid = capVid;
-	g_mutex_unlock(pdata->mutex);
+	__UNLOCK_MUTEX(__AMUTEX);
 	/*wait for flag from video thread that recording has stopped    */
 	/*wait on videoIn->VidCapStop by sleeping for 200 loops of 10 ms*/
 	/*(test VidCapStop == TRUE on every loop)*/
-	int stall = wait_ms(&(videoIn->VidCapStop), TRUE, videoIn->mutex, 10, 200);
+	int stall = wait_ms(&(videoIn->VidCapStop), TRUE, __VMUTEX, 10, 200);
 	if( !(stall > 0) )
 	{
 		g_printerr("video capture stall on exit(%d) - timeout\n",
@@ -301,7 +307,7 @@ static void closeVideoFile(struct ALL_DATA *all_data)
 	}
 	
 	/*free video buffer allocations*/
-	g_mutex_lock(global->mutex);
+	__LOCK_MUTEX(__GMUTEX);
 		//reset the indexes
 		global->r_ind=0;
 		global->w_ind=0;
@@ -316,7 +322,7 @@ static void closeVideoFile(struct ALL_DATA *all_data)
 			g_free(global->videoBuff);
 			global->videoBuff = NULL;
 		}
-	g_mutex_unlock(global->mutex);
+	__UNLOCK_MUTEX(__GMUTEX);
 	
 	switch (global->VidFormat)
 	{
@@ -347,7 +353,7 @@ static int write_video_frame (struct ALL_DATA *all_data,
 	struct GLOBAL *global = all_data->global;
 	struct GWIDGET *gwidget = all_data->gwidget;
 	
-	GThread *press_butt_thread = NULL;
+	__THREAD_TYPE press_butt_thread;
 	int ret=0;
 
 	switch (global->VidFormat)
@@ -364,18 +370,12 @@ static int write_video_frame (struct ALL_DATA *all_data,
 					if (!(global->VidButtPress))
 					{
 						global->VidButtPress = TRUE;
-						GError *err1 = NULL;
 						/*avi file limit reached - must end capture close file and start new one*/
-						if( (press_butt_thread =g_thread_create((GThreadFunc) split_avi, 
-							all_data, //data
-							FALSE,    //joinable - no need waiting for thread to finish
-							&err1)    //error
-						) == NULL)  
+						if( __THREAD_CREATE(&press_butt_thread, split_avi, all_data)) //should be created detachable
 						{
 							/*thread failed to start - stop video capture   */
 							/*can't restart since we need IO thread to stop */
-							g_printerr("Thread create failed: %s!!\n", err1->message );
-							g_error_free ( err1 ) ;
+							g_printerr("split avi: thread creation failed\n");
 							printf("stoping video capture\n");
 							if(!(global->no_display))
                             {
@@ -387,7 +387,7 @@ static int write_video_frame (struct ALL_DATA *all_data,
 							else
 							    capture_vid(NULL, all_data);
 						}
-						g_printf("AVI file size limit reached - restarted capture on new file\n");
+						g_print("AVI file size limit reached - restarted capture on new file\n");
 					}
 				} 
 				else 
@@ -418,7 +418,7 @@ static int write_audio_frame (struct ALL_DATA *all_data, void *lavc_adata, AudBu
 	struct GWIDGET *gwidget = all_data->gwidget;
 	
 	int ret =0;
-	GThread *press_butt_thread;
+	__THREAD_TYPE press_butt_thread;
 	
 	switch (global->VidFormat)
 	{
@@ -433,18 +433,14 @@ static int write_audio_frame (struct ALL_DATA *all_data, void *lavc_adata, AudBu
 					if (!(global->VidButtPress))
 					{
 						global->VidButtPress = TRUE;
-						GError *err1 = NULL;
+
 						/*avi file limit reached - must end capture close file and start new one*/
-						if( (press_butt_thread =g_thread_create((GThreadFunc) split_avi, 
-							all_data, //data
-							FALSE,    //joinable - no need waiting for thread to finish
-							&err1)    //error
-						) == NULL)  
+						if( __THREAD_CREATE(&press_butt_thread, split_avi, all_data))  //should be created detachable
 						{
 							/*thread failed to start - stop video capture   */
 							/*can't restart since we need IO thread to stop */
-							g_printerr("Thread create failed: %s!!\n", err1->message );
-							g_error_free ( err1 ) ;
+							g_printerr("split avi: thread creation failed\n");
+							
 							printf("stoping video capture\n");
 							if(!(global->no_display))
                             {
@@ -458,7 +454,7 @@ static int write_audio_frame (struct ALL_DATA *all_data, void *lavc_adata, AudBu
 						}
 					
 						//split_avi(all_data);/*blocking call*/
-						g_printf("AVI file size limit reached - restarted capture on new file\n");
+						g_print("AVI file size limit reached - restarted capture on new file\n");
 					}
 				} 
 				else 
@@ -469,12 +465,12 @@ static int write_audio_frame (struct ALL_DATA *all_data, void *lavc_adata, AudBu
 			}
 			break;
 		case MKV_FORMAT:
-			g_mutex_lock( pdata->mutex ); //why do we need this ???
+			__LOCK_MUTEX( __AMUTEX ); //why do we need this ???
 				/*set pts*/
 				videoF->apts = proc_buff->time_stamp;
 				/*write audio chunk*/
 				ret = compress_audio_frame(all_data, lavc_adata, proc_buff);
-			g_mutex_unlock( pdata->mutex );
+			__UNLOCK_MUTEX( __AMUTEX );
 			break;
 			
 		default:
@@ -501,14 +497,14 @@ static int sync_audio_frame(struct ALL_DATA *all_data, AudBuff *proc_buff)
 				/*only 1 audio stream*/
 				/*time diff for audio-video*/
 				int synctime= (int) (pdata->delay + pdata->snd_begintime - pdata->ts_ref)/1000000; /*convert to miliseconds*/
-				if (global->debug) g_printf("shift sound by %d ms\n", synctime);
+				if (global->debug) g_print("shift sound by %d ms\n", synctime);
 				if(synctime>10 && synctime<2000) 
 				{ 	/*only sync between 10ms and 2 seconds*/
 					if(global->Sound_Format == PA_FOURCC) 
 					{	/*shift sound by synctime*/
 						UINT32 shiftFrames = abs(synctime * global->Sound_SampRate / 1000);
 						UINT32 shiftSamples = shiftFrames * global->Sound_NumChan;
-						if (global->debug) g_printf("shift sound forward by %d samples\n", 
+						if (global->debug) g_print("shift sound forward by %d samples\n", 
 							shiftSamples);
 						short *EmptySamp;
 						EmptySamp=g_new0(short, shiftSamples);
@@ -562,19 +558,19 @@ static void process_audio(struct ALL_DATA *all_data,
 {
 	struct paRecordData *pdata = all_data->pdata;
 
-	g_mutex_lock( pdata->mutex );
+	__LOCK_MUTEX( __AMUTEX );
 		gboolean used = pdata->audio_buff[pdata->r_ind].used;
-	g_mutex_unlock( pdata->mutex );
+	__UNLOCK_MUTEX( __AMUTEX );
   
 	/*read at most 10 audio Frames (1152 * channels  samples each)*/
 	if(used)
 	{
-		g_mutex_lock( pdata->mutex );
+		__LOCK_MUTEX( __AMUTEX );
 			memcpy(aud_proc_buff->frame, pdata->audio_buff[pdata->r_ind].frame, pdata->aud_numSamples*sizeof(SAMPLE));
 			pdata->audio_buff[pdata->r_ind].used = FALSE;
 			aud_proc_buff->time_stamp = pdata->audio_buff[pdata->r_ind].time_stamp;
 			NEXT_IND(pdata->r_ind, AUDBUFF_SIZE);	
-		g_mutex_unlock( pdata->mutex ); /*now we should be able to unlock the audio mutex*/	
+		__UNLOCK_MUTEX( __AMUTEX ); /*now we should be able to unlock the audio mutex*/	
 		sync_audio_frame(all_data, aud_proc_buff);	
 		/*run effects on data*/
 		/*echo*/
@@ -641,45 +637,45 @@ static gboolean process_video(struct ALL_DATA *all_data,
 	int64_t max_drift = 0, audio_drift = 0;
 	
 	if (global->Sound_enable) {
-		g_mutex_lock(pdata->mutex);
+		__LOCK_MUTEX(__AMUTEX);
 			audio_drift = pdata->ts_drift;
-		g_mutex_unlock(pdata->mutex);
+		__UNLOCK_MUTEX(__AMUTEX);
 		max_drift = 1000000000 / global->fps;	/* one frame */
 	}
 
-	g_mutex_lock(videoIn->mutex);
+	__LOCK_MUTEX(__VMUTEX);
 		gboolean capVid = videoIn->capVid;
-	g_mutex_unlock(videoIn->mutex);
+	__UNLOCK_MUTEX(__VMUTEX);
 	
 	gboolean finish = FALSE;
 	
-	g_mutex_lock(global->mutex);
-    		gboolean used = global->videoBuff[global->r_ind].used;
-    	g_mutex_unlock(global->mutex);
+	__LOCK_MUTEX(__GMUTEX);
+    	gboolean used = global->videoBuff[global->r_ind].used;
+    __UNLOCK_MUTEX(__GMUTEX);
 	if (used)
 	{
-		g_mutex_lock(global->mutex);
+		__LOCK_MUTEX(__GMUTEX);
 	    		/*read video Frame*/
 			proc_buff->bytes_used = global->videoBuff[global->r_ind].bytes_used;
 			memcpy(proc_buff->frame, global->videoBuff[global->r_ind].frame, proc_buff->bytes_used);
 			proc_buff->time_stamp = global->videoBuff[global->r_ind].time_stamp;
 			global->videoBuff[global->r_ind].used = FALSE;
 			/*signals an empty slot in the video buffer*/
-			g_cond_broadcast(global->IO_cond);
+			__COND_BCAST(__GCOND);
 				
 			NEXT_IND(global->r_ind,global->video_buff_size);
 			audio_drift -= global->av_drift;
-		g_mutex_unlock(global->mutex);
+		__UNLOCK_MUTEX(__GMUTEX);
 
 		/* fprintf(stderr, "audio drift = %lli ms\n", audio_drift / 1000000); */
 		/*process video Frame*/
 		if (audio_drift > max_drift)
 		{
 			/* audio delayed */
-			g_printf("audio drift: dropping/shifting frame\n");
-			g_mutex_lock(global->mutex);
+			g_print("audio drift: dropping/shifting frame\n");
+			__LOCK_MUTEX(__GMUTEX);
 				global->av_drift += max_drift;
-			g_mutex_unlock(global->mutex);
+			__UNLOCK_MUTEX(__GMUTEX);
 
 			switch (global->VidFormat)
 			{
@@ -698,10 +694,10 @@ static gboolean process_video(struct ALL_DATA *all_data,
 		else if (audio_drift < -1 * max_drift)
 		{
 			/* audio too fast */
-			g_printf("audio drift: duplicating/shifting frame\n");
-			g_mutex_lock(global->mutex);
+			g_print("audio drift: duplicating/shifting frame\n");
+			__LOCK_MUTEX(__GMUTEX);
 				global->av_drift -= max_drift;
-			g_mutex_unlock(global->mutex);
+			__UNLOCK_MUTEX(__GMUTEX);
 
 			switch (global->VidFormat)
 			{
@@ -786,12 +782,12 @@ int store_video_frame(void *data)
 	int ret = 0;
 	int producer_sleep = 0;
 	
-	g_mutex_lock(global->mutex);
+	__LOCK_MUTEX(__GMUTEX);
 	
 	if(!global->videoBuff)
 	{
 		g_printerr("WARNING: video ring buffer not allocated yet - dropping frame.");
-		g_mutex_unlock(global->mutex);
+		__UNLOCK_MUTEX(__GMUTEX);
 		return(-1);
 	}
 	
@@ -804,13 +800,11 @@ int store_video_frame(void *data)
 	else
 	{
 		if(global->debug) g_printerr("WARNING: buffer full waiting for free space\n");
-		/*wait for IO_cond at least 200ms*/
-		GTimeVal *timev;
-		timev = g_new0(GTimeVal, 1);
-		g_get_current_time(timev); 
-		g_time_val_add(timev,100*1000); /*100 ms*/
-		/* WARNING: if system time changes it can cause undesired behaviour */
-		if(g_cond_timed_wait(global->IO_cond, global->mutex, timev))
+		/*wait for IO_cond at least 100ms*/
+		struct timespec endtime;
+		clock_gettime(CLOCK_REALTIME, &endtime);
+		endtime.tv_nsec += 10000;
+		if(__COND_TIMED_WAIT(__GCOND, __GMUTEX, &endtime))
 		{
 			/*try to store the frame again*/
 			if (!global->videoBuff[global->w_ind].used)
@@ -823,12 +817,10 @@ int store_video_frame(void *data)
 			
 		}
 		else ret = -3;/*drop frame*/
-		
-		g_free(timev);
 	}
 	if(!ret) global->framecount++;
 	
-	g_mutex_unlock(global->mutex);
+	__UNLOCK_MUTEX(__GMUTEX);
 	
 	/*-------------if needed, make the thread sleep for a while----------------*/
 	if(producer_sleep) sleep_ms(producer_sleep);
@@ -851,9 +843,9 @@ void *IO_loop(void *data)
 	struct audio_effects *aud_eff = NULL;
 	
 	gboolean finished=FALSE;
-	g_mutex_lock(videoIn->mutex);
+	__LOCK_MUTEX(__VMUTEX);
 		videoIn->IOfinished=FALSE;
-	g_mutex_unlock(videoIn->mutex);
+	__UNLOCK_MUTEX(__VMUTEX);
 	
 	gboolean capVid=FALSE;
     
@@ -890,7 +882,7 @@ void *IO_loop(void *data)
 	}
 	else
 	{
-		if(global->debug) g_printf("IO thread started...OK\n");
+		if(global->debug) g_print("IO thread started...OK\n");
 		frame_size = global->height*global->width*2;
 		proc_buff = g_new0(VidBuff, 1);
 		proc_buff->frame = g_new0(BYTE, frame_size);
@@ -911,12 +903,12 @@ void *IO_loop(void *data)
 		{
 			if(global->Sound_enable)
 			{
-				g_mutex_lock(videoIn->mutex);
+				__LOCK_MUTEX(__VMUTEX);
 					capVid = videoIn->capVid;
-				g_mutex_unlock(videoIn->mutex);
+				__UNLOCK_MUTEX(__VMUTEX);
 
-				g_mutex_lock( pdata->mutex );
-				g_mutex_lock( global->mutex );
+				__LOCK_MUTEX( __AMUTEX );
+				__LOCK_MUTEX( __GMUTEX );
 					//check read/write index delta in frames 
 					if(global->w_ind >= global->r_ind)
 						diff_ind = global->w_ind - global->r_ind;
@@ -941,18 +933,18 @@ void *IO_loop(void *data)
 						proc_flag = 1;    //process audio
 					}
 					else proc_flag = 2;    //process video
-				g_mutex_unlock( global->mutex );
-				g_mutex_unlock( pdata->mutex );
+				__UNLOCK_MUTEX( __GMUTEX );
+				__UNLOCK_MUTEX( __AMUTEX );
 			
 			
 				switch(proc_flag)
 				{
 					case 1:
-						//g_printf("processing audio frame\n");
+						//g_print("processing audio frame\n");
 						process_audio(all_data, aud_proc_buff, (void *) &lavc_audio_data, &(aud_eff));
 						break;
 					case 2:
-						//g_printf("processing video frame\n");
+						//g_print("processing video frame\n");
 						finished = process_video (all_data, proc_buff, &(lavc_data), &(jpg_data));
 						break;
 					default:
@@ -969,7 +961,7 @@ void *IO_loop(void *data)
 			if(finished)
 			{
 				//wait for audio to finish
-				int stall = wait_ms(&(pdata->streaming), FALSE, pdata->mutex, 10, 25);
+				int stall = wait_ms(&(pdata->streaming), FALSE, __AMUTEX, 10, 25);
 				if( !(stall > 0) )
 				{
 					g_printerr("audio streaming stalled - timeout\n");
@@ -1009,12 +1001,12 @@ void *IO_loop(void *data)
 	if(global->jpeg != NULL) g_free(global->jpeg); //jpeg buffer used in encoding
 	global->jpeg = NULL;
 	
-	if(global->debug) g_printf("IO thread finished...OK\n");
+	if(global->debug) g_print("IO thread finished...OK\n");
 
 	global->VidButtPress = FALSE;
-	g_mutex_lock(videoIn->mutex);
+	__LOCK_MUTEX(__VMUTEX);
 		videoIn->IOfinished=TRUE;
-	g_mutex_unlock(videoIn->mutex);
+	__UNLOCK_MUTEX(__VMUTEX);
 	
 	return ((void *) 0);
 }
