@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #                                                                               #
@@ -37,6 +37,23 @@
 
 #define ODD(x) ((x%2)?TRUE:FALSE)
 
+#define __THREAD_TYPE pthread_t
+#define __THREAD_CREATE(t,f,d) (pthread_create(t,NULL,f,d))
+#define __THREAD_JOIN(t) (pthread_join(t, NULL))
+
+
+#define __MUTEX_TYPE pthread_mutex_t
+#define __COND_TYPE pthread_cond_t
+#define __INIT_MUTEX(m) ( pthread_mutex_init(m, NULL) )
+#define __CLOSE_MUTEX(m) ( pthread_mutex_destroy(m) )
+#define __LOCK_MUTEX(m) ( pthread_mutex_lock(m) )
+#define __UNLOCK_MUTEX(m) ( pthread_mutex_unlock(m) )
+
+#define __INIT_COND(c)  ( pthread_cond_init (c, NULL) )
+#define __CLOSE_COND(c) ( pthread_cond_destroy(c) )
+#define __COND_BCAST(c) ( pthread_cond_broadcast(c) ) 
+#define __COND_TIMED_WAIT(c,m,t) ( pthread_cond_timedwait(c,m,t) )
+
 /*next index of ring buffer with size elements*/
 #define NEXT_IND(ind,size) ind++;if(ind>=size) ind=0
 /*previous index of ring buffer with size elements*/
