@@ -1,11 +1,12 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #           Nobuhiro Iwamatsu <iwamatsu@nigauri.org>                            #
 #           Dr. Alexander K. Seewald <alex@seewald.at>                          #
 #                             Autofocus algorithm                               #
 #           Flemming Frandsen <dren.dk@gmail.com>                               #
+#           George Sedov <radist.morse@gmail.com>                               #
 #                                                                               #
 # This program is free software; you can redistribute it and/or modify          #
 # it under the terms of the GNU General Public License as published by          #
@@ -49,6 +50,7 @@
 #include "string_utils.h"
 #include "options.h"
 #include "video.h"
+#include "lavc_common.h"
 #include "vcodecs.h"
 #include "create_video.h"
 #include "profile.h"
@@ -59,6 +61,9 @@
 #include "audio_tab.h"
 #include "timers.h"
 
+#define __AMUTEX &pdata->mutex
+
+
 /*----------------------------- globals --------------------------------------*/
 
 struct paRecordData *pdata = NULL;
@@ -73,7 +78,7 @@ struct VidState *s = NULL;
 struct GWIDGET *gwidget = NULL;
 
 /*thread definitions*/
-GThread *video_thread = NULL;
+//__THREAD_TYPE video_thread;
 
 /* 
  * Unix signals that are cought are written to a pipe. The pipe connects 
@@ -134,7 +139,7 @@ gboolean deliver_signal(GIOChannel *source, GIOCondition cond, gpointer data)
        */
       if(bytes_read != sizeof(int)){
 	fprintf(stderr, "lost data in signal pipe (expected %lu, received %lu)\n",
-		sizeof(int), bytes_read);
+		(long unsigned int) sizeof(int), (long unsigned int) bytes_read);
 	continue;	      /* discard the garbage and keep fingers crossed */
       }
 
@@ -184,19 +189,10 @@ int main(int argc, char *argv[])
   	GError *error = NULL;	/* handle errors */
   	
 	/*print package name and version*/ 
-	g_printf("%s\n", PACKAGE_STRING);
+	g_print("%s\n", PACKAGE_STRING);
 	
-	/* initialize glib threads - make glib thread safe*/ 
-	if( !g_thread_supported() )
-	{
-		g_thread_init(NULL);
-		gdk_threads_init ();
-	}
-	else
-	{
-		g_printerr("Fatal:g_thread NOT supported\n");
-		exit(1);
-	}
+	g_type_init ();
+	gdk_threads_init();
 	
 #ifdef ENABLE_NLS
 	char* lc_all = setlocale (LC_ALL, "");
@@ -261,26 +257,27 @@ int main(int argc, char *argv[])
 		pdata = g_new0(struct paRecordData, 1);
 
 		/*create mutex for sound buffers*/
-		pdata->mutex = g_mutex_new();
+		__INIT_MUTEX(__AMUTEX);
 
 		/* Allocate the video Format struct */
 		videoF = g_new0(struct VideoFormatData, 1);
-
-		// must be called before using avcodec lib
+		
+#if !LIBAVCODEC_VER_AT_LEAST(53,34)
 		avcodec_init();
+#endif
 
 		// register all the codecs (you can also register only the codec
-		//you wish to have smaller code
+		//you wish to have smaller code)
 		avcodec_register_all();
 
 		/*---------------------------- Start PortAudio API -----------------------*/
-		if(global->debug) g_printf("starting portaudio...\n");
+		if(global->debug) g_print("starting portaudio...\n");
 		Pa_Initialize(); 
 	}
 
 #ifdef ENABLE_NLS
 	/* if --verbose mode set do debug*/
-	if (global->debug) g_printf("language catalog=> dir:%s type:%s lang:%s cat:%s.mo\n",
+	if (global->debug) g_print("language catalog=> dir:%s type:%s lang:%s cat:%s.mo\n",
 		lc_dir, lc_all, langs[0], txtdom);
 #endif
 	/*---------------------------- GTK init ----------------------------------*/
@@ -298,9 +295,26 @@ int main(int argc, char *argv[])
         /* Create a main window */
         gwidget->mainwin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
         gtk_window_set_title (GTK_WINDOW (gwidget->mainwin), _("GUVCViewer Controls"));
+        //get screen resolution
+        if((!global->desktop_w) || (!global->desktop_h))
+        {
+            GdkScreen* screen = NULL;
+            screen = gtk_window_get_screen(GTK_WINDOW(gwidget->mainwin));
+            global->desktop_w = gdk_screen_get_width(screen);
+            global->desktop_h = gdk_screen_get_height(screen);
+        }
+        if(global->debug)
+            g_print("Screen resolution is (%d x %d)\n", global->desktop_w, global->desktop_h);
+        
+        if((global->winwidth > global->desktop_w) && (global->desktop_w > 0))
+            global->winwidth = global->desktop_w;
+        if((global->winheight > global->desktop_h) && (global->desktop_h > 0))
+            global->winheight = global->desktop_h;
+        
         gtk_window_resize(GTK_WINDOW(gwidget->mainwin),global->winwidth,global->winheight);
+        
         /* Add event handlers */
-        gtk_signal_connect(GTK_OBJECT(gwidget->mainwin), "delete_event", GTK_SIGNAL_FUNC(delete_event), &all_data);
+        g_signal_connect(GTK_WINDOW(gwidget->mainwin), "delete_event", G_CALLBACK(delete_event), &all_data);
     }
 
 	/*----------------------- init videoIn structure --------------------------*/
@@ -317,7 +331,7 @@ int main(int argc, char *argv[])
 
 	/*get format from selected mode*/
 	global->format = get_PixFormat(global->mode);
-	if(global->debug) g_printf("%s: setting format to %i\n", global->mode, global->format);
+	if(global->debug) g_print("%s: setting format to %i\n", global->mode, global->format);
 
 	if ( ( ret=init_videoIn (videoIn, global) ) != 0)
 	{
@@ -347,7 +361,7 @@ int main(int argc, char *argv[])
 			case VDIN_UNKNOWN_ERR: //unknown error (treat as invalid format)
 			case VDIN_FORMAT_ERR://invalid format
 			case VDIN_RESOL_ERR: //invalid resolution
-				g_printf("trying minimum setup ...\n");
+				g_print("trying minimum setup ...\n");
 				if (videoIn->listFormats->numb_formats > 0) //check for supported formats
 				{
 					VidFormats *listVidFormats;
@@ -472,7 +486,7 @@ int main(int argc, char *argv[])
         
         gtk_widget_show(scroll1);
         
-        Tab1 = gtk_hbox_new(FALSE,2);
+        Tab1 = gtk_grid_new();
         Tab1Label = gtk_label_new(_("Image Controls"));
         gtk_widget_show (Tab1Label);
         /*check for files*/
@@ -482,8 +496,8 @@ int main(int argc, char *argv[])
         Tab1Icon = gtk_image_new_from_file(Tab1IconPath);
         g_free(Tab1IconPath);
         gtk_widget_show (Tab1Icon);
-        gtk_box_pack_start (GTK_BOX(Tab1), Tab1Icon, FALSE, FALSE,1);
-        gtk_box_pack_start (GTK_BOX(Tab1), Tab1Label, FALSE, FALSE,1);
+        gtk_grid_attach (GTK_GRID(Tab1), Tab1Icon, 0, 0, 1, 1);
+		gtk_grid_attach (GTK_GRID(Tab1), Tab1Label, 1, 0, 1, 1);
         
         gtk_widget_show (Tab1);
         
@@ -494,13 +508,15 @@ int main(int argc, char *argv[])
         gtk_widget_show (gwidget->boxv);
         
         /*---------------------- Add  Buttons ---------------------------------*/
-        buttons_table = gtk_table_new(1,5,FALSE);
-        HButtonBox = gtk_hbutton_box_new();
+        buttons_table = gtk_grid_new();
+        HButtonBox = gtk_button_box_new(GTK_ORIENTATION_HORIZONTAL);
+        gtk_widget_set_halign (HButtonBox, GTK_ALIGN_FILL);
+		gtk_widget_set_hexpand (HButtonBox, TRUE);
         gtk_button_box_set_layout(GTK_BUTTON_BOX(HButtonBox),GTK_BUTTONBOX_SPREAD);
         gtk_box_set_homogeneous(GTK_BOX(HButtonBox),TRUE);
 
-        gtk_table_set_row_spacings (GTK_TABLE (buttons_table), 1);
-        gtk_table_set_col_spacings (GTK_TABLE (buttons_table), 4);
+        gtk_grid_set_row_spacing (GTK_GRID(buttons_table), 1);
+		gtk_grid_set_column_spacing (GTK_GRID (buttons_table), 4);
         gtk_container_set_border_width (GTK_CONTAINER (buttons_table), 1);
         
         gtk_widget_show (buttons_table);
@@ -510,8 +526,7 @@ int main(int argc, char *argv[])
         {
             capture_labels=gtk_label_new(_("Capture:"));
             gtk_misc_set_alignment (GTK_MISC (capture_labels), 0.5, 0.5);
-            gtk_table_attach (GTK_TABLE(buttons_table), capture_labels, n, n+2, 0, 1,
-                GTK_SHRINK | GTK_FILL | GTK_EXPAND, 0, 0, 0);
+            gtk_grid_attach(GTK_GRID(buttons_table), capture_labels, n, 0, 2 , 1);
             gtk_widget_show (capture_labels);
             n+=2; //increment column for labels
         }//end of control only exclusion
@@ -519,12 +534,10 @@ int main(int argc, char *argv[])
         profile_labels=gtk_label_new(_("Control Profiles:"));
         gtk_misc_set_alignment (GTK_MISC (profile_labels), 0.5, 0.5);
 
-        gtk_table_attach (GTK_TABLE(buttons_table), profile_labels, n, n+2, 0, 1,
-            GTK_SHRINK | GTK_FILL | GTK_EXPAND , 0, 0, 0);
+        gtk_grid_attach(GTK_GRID(buttons_table), profile_labels, n, 0, 2 , 1);
         gtk_widget_show (profile_labels);
         
-        gtk_table_attach(GTK_TABLE(buttons_table), HButtonBox, 0, 5, 1, 2,
-            GTK_SHRINK | GTK_FILL | GTK_EXPAND, 0, 0, 0);
+        gtk_grid_attach(GTK_GRID(buttons_table), HButtonBox, 0, 1, 5, 1);
             
         gtk_widget_show(HButtonBox);
         
@@ -574,7 +587,7 @@ int main(int argc, char *argv[])
                 gtk_button_set_image_position(GTK_BUTTON(gwidget->CapVidButt),GTK_POS_TOP);
                 //gtk_widget_show (gwidget->VidButton_Img);
             }
-            //else g_printf("couldn't load %s\n", pix1path);
+            //else g_print("couldn't load %s\n", pix1path);
             gchar* pix2path = g_strconcat (PACKAGE_DATA_DIR,"/pixmaps/guvcview/camera.png",NULL);
             if (g_file_test(pix2path,G_FILE_TEST_EXISTS)) 
             {
@@ -598,7 +611,7 @@ int main(int argc, char *argv[])
                 G_CALLBACK (capture_vid), &all_data);
             /*key events*/
             gtk_widget_add_events (GTK_WIDGET (gwidget->mainwin), GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
-            g_signal_connect (GTK_OBJECT(gwidget->mainwin), "key_press_event", G_CALLBACK (key_pressed), &all_data);
+            g_signal_connect (GTK_WINDOW(gwidget->mainwin), "key_press_event", G_CALLBACK(key_pressed), &all_data);
         }/*end of control_only exclusion*/
         
         gchar* pix3path = g_strconcat (PACKAGE_DATA_DIR,"/pixmaps/guvcview/save.png",NULL);
@@ -669,8 +682,8 @@ int main(int argc, char *argv[])
         g_signal_connect (GTK_BUTTON(DefaultsButton), "clicked",
             G_CALLBACK (DefaultsButton_clicked), &all_data);
         
-        /*sets the pan position*/
-        if(global->boxvsize==0) 
+        /*sets the pan position (always leave enough space for the buttons)*/
+        if((global->boxvsize <= 0) || (global->boxvsize > (global->winheight-122))) 
         {
             global->boxvsize=global->winheight-122;
         }
@@ -700,25 +713,15 @@ int main(int argc, char *argv[])
 	if (!control_only) /*control_only exclusion*/
 	{
 		/*------------------ Creating the video thread ---------------*/
-		GError *err1 = NULL;
-
-		if( (video_thread = g_thread_create_full((GThreadFunc) main_loop, 
-			(void *) &all_data,       //data - argument supplied to thread
-			global->stack_size,       //stack size
-			TRUE,                     //joinable
-			TRUE,                     //bound
-			G_THREAD_PRIORITY_NORMAL, //priority - no priority for threads in GNU-Linux
-			&err1)                    //error
-		) == NULL)
+		if( __THREAD_CREATE(&all_data.video_thread, main_loop, (void *) &all_data))
 		{
-			g_printerr("Thread create failed: %s!!\n", err1->message );
-			g_error_free ( err1 ) ;
+			g_printerr("Video thread creation failed\n");
 
 			ERR_DIALOG (N_("Guvcview error:\n\nUnable to create Video Thread"),
 				N_("Please report it to http://developer.berlios.de/bugs/?group_id=8179"),
 				&all_data);      
 		}
-		all_data.video_thread = video_thread;
+		//all_data.video_thread = video_thread;
 	
 		/*---------------------- image timed capture -----------------------------*/
 		if(global->image_timer)
@@ -744,20 +747,10 @@ int main(int argc, char *argv[])
 				/*start disk check timed callback (every 10 sec)*/
 				if (!global->disk_timer_id)
 					global->disk_timer_id=g_timeout_add(10*1000, FreeDiskCheck_timer, &all_data);
-
-				GError *err1 = NULL;
 				/*start IO thread*/
-				if( (all_data.IO_thread = g_thread_create_full((GThreadFunc) IO_loop, 
-					(void *) &all_data,       //data - argument supplied to thread
-					global->stack_size,       //stack size
-					TRUE,                     //joinable
-					TRUE,                     //bound
-					G_THREAD_PRIORITY_NORMAL, //priority - no priority for threads in GNU-Linux
-					&err1)                    //error
-				) == NULL)
+				if( __THREAD_CREATE(&all_data.IO_thread, IO_loop, (void *) &all_data))
 				{
-					g_printerr("Thread create failed: %s!!\n", err1->message );
-					g_error_free ( err1 ) ;
+					g_printerr("IO thread creation failed\n");
 					cap_ok = FALSE;
 				}
 				else if (global->Capture_time) 
@@ -857,14 +850,14 @@ int main(int argc, char *argv[])
 	//closing portaudio
 	if(!control_only)
 	{
-		g_printf("Closing portaudio ...");
+		g_print("Closing portaudio ...");
 		if (Pa_Terminate() != paNoError) 
-			g_printf("Error\n");
+			g_print("Error\n");
 		else
-			g_printf("OK\n");
+			g_print("OK\n");
 	}
 	
-	g_printf("Closing GTK... OK\n");
+	g_print("Closing GTK... OK\n");
 	return 0;
 }
 
