@@ -1,9 +1,12 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #           Nobuhiro Iwamatsu <iwamatsu@nigauri.org>                            #
 #                             Add UYVY color support(Macbook iSight)            #
+#           George Sedov <radist.morse@gmail.com>                               #
+#                             Threaded encoding                                 #
+#                             default action selector for Webcam button         #
 #                                                                               #
 # This program is free software; you can redistribute it and/or modify          #
 # it under the terms of the GNU General Public License as published by          #
@@ -74,6 +77,9 @@ struct GWIDGET
 	GtkWidget *jpeg_comp;
 	GtkWidget *quitButton;
 	
+	GtkWidget *TakeImageByDefault;
+	GtkWidget *TakeVidByDefault;
+	
 	gboolean vid_widget_state;
 };
 
@@ -86,8 +92,8 @@ struct ALL_DATA
 	struct VideoFormatData *videoF;
 	struct GWIDGET *gwidget;
 	struct VidState *s;
-	GThread *video_thread;
-	GThread *IO_thread;
+	__THREAD_TYPE video_thread;
+	__THREAD_TYPE IO_thread;
 };
 
 #endif
