@@ -1,7 +1,9 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
+#           George Sedov <radist.morse@gmail.com>                               #
+#                  - Threaded encoding                                          #
 #                                                                               #
 # This program is free software; you can redistribute it and/or modify          #
 # it under the terms of the GNU General Public License as published by          #
@@ -25,6 +27,7 @@
 #include "../config.h"
 #include "defs.h"
 #include "sound.h"
+#include "video_format.h"
 
 #ifdef HAS_AVCODEC_H
   #include <avcodec.h>
@@ -40,33 +43,43 @@
   #endif
 #endif
 
+#define LIBAVCODEC_VER_AT_LEAST(major,minor)  (LIBAVCODEC_VERSION_MAJOR > major || \
+                                              (LIBAVCODEC_VERSION_MAJOR == major && \
+                                               LIBAVCODEC_VERSION_MINOR >= minor))
 /*video*/
 struct lavcData
 {
-	/*video*/
 	AVCodec *codec;
+	AVDictionary *private_options;
 	AVCodecContext *codec_context;
 	AVFrame *picture;
-
+	AVPacket *outpkt;
+	
 	BYTE* tmpbuf;
 	int outbuf_size;
 	BYTE* outbuf;
+	
+	int codec_id;
+	int monotonic_pts;
 };
 
 /*Audio*/
 struct lavcAData
 {
-	/*video*/
 	AVCodec *codec;
 	AVCodecContext *codec_context;
-
+	AVFrame *frame;
+	AVPacket *outpkt;
+	
 	int outbuf_size;
 	BYTE* outbuf;
+	
+	int monotonic_pts;
 };
 
-int encode_lavc_frame (BYTE *picture_buf, struct lavcData* data, int format);
+int encode_lavc_frame (BYTE *picture_buf, struct lavcData* data, int format, struct VideoFormatData *videoF);
 
-int encode_lavc_audio_frame (short *audio_buf, struct lavcAData* data);
+int encode_lavc_audio_frame (short *audio_buf, struct lavcAData* data, struct VideoFormatData *videoF);
 
 /* arg = pointer to lavcData struct =>
  * *arg = struct lavcData**
