@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #                                                                               #
@@ -54,6 +54,7 @@ writeConf(struct GLOBAL *global, char *videodevice)
 	if ((fp = g_fopen(tmpfile,"w"))!=NULL) 
 	{
 		g_fprintf(fp,"# guvcview configuration file for %s\n\n",videodevice);
+		g_fprintf(fp,"version='%s'\n",VERSION);
 		g_fprintf(fp,"# Thread stack size: default 128 pages of 64k = 8388608 bytes\n");
 		g_fprintf(fp,"stack_size=%d\n",global->stack_size);
 		g_fprintf(fp,"# video loop sleep time in ms: 0,1,2,3,...\n");
@@ -69,6 +70,8 @@ writeConf(struct GLOBAL *global, char *videodevice)
 		g_fprintf(fp,"vpane=%i\n",global->boxvsize);
 		g_fprintf(fp,"#spin button behavior: 0-non editable 1-editable\n");
 		g_fprintf(fp,"spinbehave=%i\n", global->spinbehave);
+		g_fprintf(fp,"#Default action. 0 for picture, 1 for video.\n");
+		g_fprintf(fp,"default_action=%i\n", global->default_action);
 		g_fprintf(fp,"# mode video format 'yuvy' 'yvyu' 'uyvy' 'yyuv' 'yu12' 'yv12' 'nv12' 'nv21' 'nv16' 'nv61' 'y41p' 'grey' 'y16 ' 's501' 's505' 's508' 'gbrg' 'grbg' 'ba81' 'rggb' 'rgb3' 'bgr3' 'jpeg' 'mjpg'(default)\n");
 		g_fprintf(fp,"mode='%s'\n",global->mode);
 		g_fprintf(fp,"# frames per sec. - hardware supported - default( %i )\n",DEFAULT_FPS);
@@ -123,6 +126,7 @@ writeConf(struct GLOBAL *global, char *videodevice)
 		g_fprintf(fp, "# video codec (%s) properties (remove for default values\n", vcodec_defaults->compressor);
 		g_fprintf(fp, "vcodec_bit_rate=%d\n",vcodec_defaults->bit_rate);
 		g_fprintf(fp, "vcodec_fps=%d\n",vcodec_defaults->fps);
+		g_fprintf(fp, "vcodec_monotonic_pts=%d\n",vcodec_defaults->monotonic_pts);
 		g_fprintf(fp, "vcodec_qmax=%d\n",vcodec_defaults->qmax);
 		g_fprintf(fp, "vcodec_qmin=%d\n",vcodec_defaults->qmin);
 		g_fprintf(fp, "vcodec_max_qdiff=%d\n",vcodec_defaults->max_qdiff);
@@ -143,6 +147,7 @@ writeConf(struct GLOBAL *global, char *videodevice)
 		g_fprintf(fp, "vcodec_me_method=%d\n",vcodec_defaults->me_method);
 		g_fprintf(fp, "vcodec_mpeg_quant=%d\n",vcodec_defaults->mpeg_quant);
 		g_fprintf(fp, "vcodec_max_b_frames=%d\n",vcodec_defaults->max_b_frames);
+		g_fprintf(fp, "vcodec_num_threads=%d\n",vcodec_defaults->num_threads);
 		g_fprintf(fp, "vcodec_flags=%d\n",vcodec_defaults->flags);
 		printf("write %s OK\n",global->confPath);
 		
@@ -179,7 +184,7 @@ int
 readConf(struct GLOBAL *global)
 {
 	int ret=0;
-	int signal=1; /*1=>+ or -1=>-*/
+	//int signal=1; /*1=>+ or -1=>-*/
 	GScanner  *scanner;
 	GTokenType ttype;
 	GScannerConfig config = 
@@ -228,9 +233,9 @@ readConf(struct GLOBAL *global)
 		int ac_bit_rate =-1, vc_bit_rate=-1, vc_fps=-1, vc_qmax=-1, vc_qmin=-1, vc_max_qdiff=-1, vc_dia=-1;
 		int vc_pre_dia=-1, vc_pre_me=-1, vc_me_pre_cmp=-1, vc_me_cmp=-1, vc_me_sub_cmp=-1, vc_last_pred=-1;
 		int vc_gop_size=-1, vc_subq=-1, vc_framerefs=-1, vc_mb_decision=-1, vc_trellis=-1, vc_me_method=-1;
-		int vc_mpeg_quant=-1, vc_max_b_frames=-1, vc_flags=-1;
+		int vc_mpeg_quant=-1, vc_max_b_frames=-1, vc_num_threads=-1, vc_flags=-1, vc_monotonic_pts=-1;
 		float vc_qcompress=-1, vc_qblur=-1;
-		
+		int VMAJOR =-1, VMINOR=-1, VMICRO=-1; 
 		
 		for (ttype = g_scanner_get_next_token (scanner);
 			ttype != G_TOKEN_EOF;
@@ -257,22 +262,28 @@ readConf(struct GLOBAL *global)
 					/*check for signed integers*/
 					if(ttype == '-')
 					{
-						signal = -1;
+						//signal = -1;
 						ttype = g_scanner_get_next_token (scanner);
 					}
 					
 					if (ttype == G_TOKEN_STRING)
 					{
-						signal=1; /*reset signal*/
+						//signal=1; /*reset signal*/
 						//if (g_strcmp0(name,"video_device")==0) 
 						//{
 						//	g_snprintf(global->videodevice,15,"%s",scanner->value.v_string);
 						//}
 						
-						/*must check for defaults since ReadOpts runs before ReadConf*/
-						if (g_strcmp0(name,"resolution")==0) 
+						if (g_strcmp0(name,"version")==0)
 						{
-							if(global->flg_res < 1)
+							sscanf(scanner->value.v_string,"%i.%i.%i",
+								&(VMAJOR), 
+								&(VMINOR),
+								&(VMICRO));
+						}
+						else if (g_strcmp0(name,"resolution")==0) 
+						{
+							if(global->flg_res < 1) /*must check for defaults since ReadOpts runs before ReadConf*/
 								sscanf(scanner->value.v_string,"%ix%i",
 									&(global->width), 
 									&(global->height));
@@ -369,6 +380,10 @@ readConf(struct GLOBAL *global)
 						{
 							global->spinbehave = scanner->value.v_int;
 						}
+						else if (g_strcmp0(name,"default_action")==0)
+						{
+							global->default_action = scanner->value.v_int;
+						}
 						else if (g_strcmp0(name,"fps")==0)
 						{
 							/*parse non-quoted fps values*/
@@ -505,6 +520,10 @@ readConf(struct GLOBAL *global)
 						{
 						    vc_fps = scanner->value.v_int;
 						}
+						else if (g_strcmp0(name,"vcodec_monotonic_pts")==0) 
+						{
+						    vc_monotonic_pts = scanner->value.v_int;
+						}
 						else if (g_strcmp0(name,"vcodec_qmax")==0) 
 						{
 						    vc_qmax = scanner->value.v_int;
@@ -581,6 +600,10 @@ readConf(struct GLOBAL *global)
 						{
 						    vc_flags = scanner->value.v_int;
 						}
+						else if (g_strcmp0(name,"vcodec_num_threads")==0)
+						{
+						    vc_num_threads = scanner->value.v_int;
+						}
 						else
 						{
 							printf("unexpected integer value (%lu) for %s\n", 
@@ -648,6 +671,8 @@ readConf(struct GLOBAL *global)
         if (ac_bit_rate >= 0) acodec_defaults->bit_rate = ac_bit_rate;
         if (vc_bit_rate >= 0) vcodec_defaults->bit_rate = vc_bit_rate;
         if (vc_fps >= 0) vcodec_defaults->fps = vc_fps;
+        //from 1.5.3 onwards we set version on conf file and monotonic is set by default for all codecs
+        if ((vc_monotonic_pts >= 0) && (VMAJOR > 0)) vcodec_defaults->monotonic_pts = vc_monotonic_pts;
 		if (vc_qmax >= 0) vcodec_defaults->qmax = vc_qmax;
 		if (vc_qmin >= 0) vcodec_defaults->qmin = vc_qmin;
 		if (vc_max_qdiff >=0) vcodec_defaults->max_qdiff = vc_max_qdiff;
@@ -666,37 +691,39 @@ readConf(struct GLOBAL *global)
 		if (vc_me_method >=0) vcodec_defaults->me_method = vc_me_method;
 		if (vc_mpeg_quant >=0) vcodec_defaults->mpeg_quant = vc_mpeg_quant;
 		if (vc_max_b_frames >=0) vcodec_defaults->max_b_frames = vc_max_b_frames;
+		if (vc_num_threads >=0) vcodec_defaults->num_threads = vc_num_threads;
         if (vc_flags >=0) vcodec_defaults->flags = vc_flags;
         if (vc_qcompress >= 0) vcodec_defaults->qcompress = vc_qcompress;
 		if (vc_qblur >=0) vcodec_defaults->qblur = vc_qblur;
         
 		if (global->debug) 
 		{
-			g_printf("video_device: %s\n",global->videodevice);
-			g_printf("vid_sleep: %i\n",global->vid_sleep);
-			g_printf("cap_meth: %i\n",global->cap_meth);
-			g_printf("resolution: %i x %i\n",global->width,global->height);
-			g_printf("windowsize: %i x %i\n",global->winwidth,global->winheight);
-			g_printf("vert pane: %i\n",global->boxvsize);
-			g_printf("spin behavior: %i\n",global->spinbehave);
-			g_printf("mode: %s\n",global->mode);
-			g_printf("fps: %i/%i\n",global->fps_num,global->fps);
-			g_printf("Display Fps: %i\n",global->FpsCount);
-			g_printf("bpp: %i\n",global->bpp);
-			g_printf("hwaccel: %i\n",global->hwaccel);
-			g_printf("avi_format: %i\n",global->VidCodec);
-			g_printf("sound: %i\n",global->Sound_enable);
-			g_printf("sound Device: %i\n",global->Sound_UseDev);
-			g_printf("sound samp rate: %i\n",global->Sound_SampRateInd);
-			g_printf("sound Channels: %i\n",global->Sound_NumChanInd);
-			g_printf("Sound delay: %llu nanosec\n",(unsigned long long) global->Sound_delay);
-			g_printf("Sound Format: %i \n",global->Sound_Format);
-			//g_printf("Sound bit Rate: %i Kbps\n",global->Sound_bitRate);
-			g_printf("Pan Step: %i degrees\n",global->PanStep);
-			g_printf("Tilt Step: %i degrees\n",global->TiltStep);
-			g_printf("Video Filter Flags: %i\n",global->Frame_Flags);
-			g_printf("image inc: %d\n",global->image_inc);
-			g_printf("profile(default):%s/%s\n",global->profile_FPath[1],global->profile_FPath[0]);
+			g_print("video_device: %s\n",global->videodevice);
+			g_print("vid_sleep: %i\n",global->vid_sleep);
+			g_print("cap_meth: %i\n",global->cap_meth);
+			g_print("resolution: %i x %i\n",global->width,global->height);
+			g_print("windowsize: %i x %i\n",global->winwidth,global->winheight);
+			g_print("vert pane: %i\n",global->boxvsize);
+			g_print("spin behavior: %i\n",global->spinbehave);
+			g_print("default action: %i\n",global->default_action);
+			g_print("mode: %s\n",global->mode);
+			g_print("fps: %i/%i\n",global->fps_num,global->fps);
+			g_print("Display Fps: %i\n",global->FpsCount);
+			g_print("bpp: %i\n",global->bpp);
+			g_print("hwaccel: %i\n",global->hwaccel);
+			g_print("avi_format: %i\n",global->VidCodec);
+			g_print("sound: %i\n",global->Sound_enable);
+			g_print("sound Device: %i\n",global->Sound_UseDev);
+			g_print("sound samp rate: %i\n",global->Sound_SampRateInd);
+			g_print("sound Channels: %i\n",global->Sound_NumChanInd);
+			g_print("Sound delay: %llu nanosec\n",(unsigned long long) global->Sound_delay);
+			g_print("Sound Format: %i \n",global->Sound_Format);
+			//g_print("Sound bit Rate: %i Kbps\n",global->Sound_bitRate);
+			g_print("Pan Step: %i degrees\n",global->PanStep);
+			g_print("Tilt Step: %i degrees\n",global->TiltStep);
+			g_print("Video Filter Flags: %i\n",global->Frame_Flags);
+			g_print("image inc: %d\n",global->image_inc);
+			g_print("profile(default):%s/%s\n",global->profile_FPath[1],global->profile_FPath[0]);
 		}
 	}
 	
@@ -771,7 +798,7 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 		g_error_free ( error );
 		closeGlobals(global);
 		global=NULL;
-		g_printf("%s",help_all_str);
+		g_print("%s",help_all_str);
 		g_free(help_all_str);
 		g_free(help_str);
 		g_free(help_gtk_str);
@@ -796,7 +823,7 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 	{
 		closeGlobals(global);
 		global=NULL;
-		g_printf("%s",help_all_str);
+		g_print("%s",help_all_str);
 		g_free(help_all_str);
 		g_free(help_str);
 		g_free(help_gtk_str);
@@ -807,7 +834,7 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 	{
 		closeGlobals(global);
 		global=NULL;
-		g_printf("%s",help_str);
+		g_print("%s",help_str);
 		g_free(help_str);
 		g_free(help_gtk_str);
 		g_free(help_all_str);
@@ -817,7 +844,7 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 	{
 		closeGlobals(global);
 		global=NULL;
-		g_printf("%s",help_gtk_str);
+		g_print("%s",help_gtk_str);
 		g_free(help_str);
 		g_free(help_gtk_str);
 		g_free(help_all_str);
@@ -915,13 +942,13 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 	}
 	if(global->image_timer > 0 )
 	{
-		g_printf("capturing images every %i seconds\n",global->image_timer);
+		g_print("capturing images every %i seconds\n",global->image_timer);
 	}
 	if(video)
 	{
 		global->vidfile = g_strdup(video);
 		global->vidFPath=splitPath(global->vidfile,global->vidFPath);
-		g_printf("capturing video: %s , from start\n",global->vidfile);
+		g_print("capturing video: %s , from start\n",global->vidfile);
 		/*get the file type*/
 		global->VidFormat = check_video_type(global->vidFPath[0]);
 	}
@@ -946,7 +973,7 @@ readOpts(int argc,char *argv[], struct GLOBAL *global)
 		global->cap_meth = cap_meth;
 	}
 	
-	//g_printf("option capture meth is %i\n", global->cap_meth);
+	//g_print("option capture meth is %i\n", global->cap_meth);
 	g_free(help_str);
 	g_free(help_gtk_str);
 	g_free(help_all_str);
