@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #                                                                               #
@@ -299,7 +299,7 @@ int write_png(char *file_name, int width, int height,BYTE *prgb_data)
 	text_ptr[1].text = "guvcview";
 	text_ptr[1].compression = PNG_TEXT_COMPRESSION_NONE;
 	text_ptr[2].key = "Description";
-	text_ptr[2].text = "File generated by guvcview <http://guvcview.berlios.de>";
+	text_ptr[2].text = "File generated by guvcview <http://guvcview.sourceforge.net>";
 	text_ptr[2].compression = PNG_TEXT_COMPRESSION_NONE;
 #ifdef PNG_iTXt_SUPPORTED
 	text_ptr[0].lang = NULL;
