@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #                                                                               #
@@ -29,15 +29,15 @@ list_snd_devices(struct GLOBAL *global)
 	int   it, numDevices, defaultDisplayed;
 	const PaDeviceInfo *deviceInfo;
 
-	PaError err;
+	//PaError err;
 	/*sound device combo box*/
-	GtkWidget *SndDevice = gtk_combo_box_new_text ();
+	GtkWidget *SndDevice = gtk_combo_box_text_new ();
 	
 	numDevices = Pa_GetDeviceCount();
 	if( numDevices < 0 )
 	{
-		g_printf( "SOUND DISABLE: Pa_CountDevices returned 0x%x\n", numDevices );
-		err = numDevices;
+		g_print( "SOUND DISABLE: Pa_CountDevices returned 0x%x\n", numDevices );
+		//err = numDevices;
 		global->Sound_enable=0;
 	} 
 	else 
@@ -47,21 +47,21 @@ list_snd_devices(struct GLOBAL *global)
 		for( it=0; it<numDevices; it++ )
 		{
 			deviceInfo = Pa_GetDeviceInfo( it );
-			if (global->debug) g_printf( "--------------------------------------- device #%d\n", it );
+			if (global->debug) g_print( "--------------------------------------- device #%d\n", it );
 			// Mark global and API specific default devices
 			defaultDisplayed = 0;
 			
 			// with pulse, ALSA is now listed first and doesn't set a API default- 11-2009
 			if( it == Pa_GetDefaultInputDevice() )
 			{
-				if (global->debug) g_printf( "[ Default Input" );
+				if (global->debug) g_print( "[ Default Input" );
 				defaultDisplayed = 1;
 				global->Sound_DefDev=global->Sound_numInputDev;/*default index in array of input devs*/
 			}
 			else if( it == Pa_GetHostApiInfo( deviceInfo->hostApi )->defaultInputDevice )
 			{
 				const PaHostApiInfo *hostInfo = Pa_GetHostApiInfo( deviceInfo->hostApi );
-				if (global->debug) g_printf( "[ Default %s Input", hostInfo->name );
+				if (global->debug) g_print( "[ Default %s Input", hostInfo->name );
 				defaultDisplayed = 2;
 				//global->Sound_DefDev=global->Sound_numInputDev;/*index in array of input devs*/
 			}
@@ -70,8 +70,8 @@ list_snd_devices(struct GLOBAL *global)
 			{
 			 	if (global->debug) 
 				{
-					g_printf( (defaultDisplayed ? "," : "[") );
-					g_printf( " Default Output" );
+					g_print( (defaultDisplayed ? "," : "[") );
+					g_print( " Default Output" );
 				}
 				defaultDisplayed = 3;
 			}
@@ -80,21 +80,21 @@ list_snd_devices(struct GLOBAL *global)
 				const PaHostApiInfo *hostInfo = Pa_GetHostApiInfo( deviceInfo->hostApi );
 				if (global->debug)
 				{
-					g_printf( (defaultDisplayed ? "," : "[") );                
-					g_printf( " Default %s Output", hostInfo->name );/* OSS ALSA etc*/
+					g_print( (defaultDisplayed ? "," : "[") );                
+					g_print( " Default %s Output", hostInfo->name );/* OSS ALSA etc*/
 				}
 				defaultDisplayed = 4;
 			}
 
 			if( defaultDisplayed!=0 )
-				if (global->debug) g_printf( " ]\n" );
+				if (global->debug) g_print( " ]\n" );
 
 			/* print device info fields */
 			if (global->debug) 
 			{
-				g_printf( "Name                     = %s\n", deviceInfo->name );
-				g_printf( "Host API                 = %s\n",  Pa_GetHostApiInfo( deviceInfo->hostApi )->name );
-				g_printf( "Max inputs = %d", deviceInfo->maxInputChannels  );
+				g_print( "Name                     = %s\n", deviceInfo->name );
+				g_print( "Host API                 = %s\n",  Pa_GetHostApiInfo( deviceInfo->hostApi )->name );
+				g_print( "Max inputs = %d", deviceInfo->maxInputChannels  );
 			}
 			// INPUT devices (if it has input channels it's a capture device)
 			if (deviceInfo->maxInputChannels >0) 
@@ -108,21 +108,21 @@ list_snd_devices(struct GLOBAL *global)
 				global->Sound_IndexDev[global->Sound_numInputDev-1].samprate=deviceInfo->defaultSampleRate;
 				//Sound_IndexDev[Sound_numInputDev].Hlatency=deviceInfo->defaultHighInputLatency;
 				//Sound_IndexDev[Sound_numInputDev].Llatency=deviceInfo->defaultLowInputLatency;
-				gtk_combo_box_append_text(GTK_COMBO_BOX(SndDevice),deviceInfo->name);
+				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(SndDevice),deviceInfo->name);
 			}
 			if (global->debug) 
 			{
-				g_printf( ", Max outputs = %d\n", deviceInfo->maxOutputChannels  );
-				g_printf( "Def. low input latency   = %8.3f\n", deviceInfo->defaultLowInputLatency  );
-				g_printf( "Def. low output latency  = %8.3f\n", deviceInfo->defaultLowOutputLatency  );
-				g_printf( "Def. high input latency  = %8.3f\n", deviceInfo->defaultHighInputLatency  );
-				g_printf( "Def. high output latency = %8.3f\n", deviceInfo->defaultHighOutputLatency  );
-				g_printf( "Def. sample rate         = %8.2f\n", deviceInfo->defaultSampleRate );
+				g_print( ", Max outputs = %d\n", deviceInfo->maxOutputChannels  );
+				g_print( "Def. low input latency   = %8.3f\n", deviceInfo->defaultLowInputLatency  );
+				g_print( "Def. low output latency  = %8.3f\n", deviceInfo->defaultLowOutputLatency  );
+				g_print( "Def. high input latency  = %8.3f\n", deviceInfo->defaultHighInputLatency  );
+				g_print( "Def. high output latency = %8.3f\n", deviceInfo->defaultHighOutputLatency  );
+				g_print( "Def. sample rate         = %8.2f\n", deviceInfo->defaultSampleRate );
 			}
 			
 		}
 		
-		if (global->debug) g_printf("----------------------------------------------\n");
+		if (global->debug) g_print("----------------------------------------------\n");
 	}
 	
 	return (SndDevice);
