@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #                                                                               #
@@ -35,6 +35,8 @@
 #include "callbacks.h"
 #include "close.h"
 
+#define __VMUTEX &videoIn->mutex
+
 /* called for timed shutdown (from video thread)*/
 gboolean
 shutd_timer(gpointer data)
@@ -54,7 +56,7 @@ timer_callback(gpointer data)
     struct GWIDGET *gwidget = all_data->gwidget;
     
     /*stop video capture*/
-    if(global->debug) g_printf("setting video toggle to FALSE\n");
+    if(global->debug) g_print("setting video toggle to FALSE\n");
     
     if(!global->no_display)
     {
@@ -86,13 +88,10 @@ Image_capture_timer(gpointer data)
     struct vdIn *videoIn = all_data->videoIn; 
     
     /*increment image name */
-    //g_mutex_lock(videoIn->mutex);
     videoIn->ImageFName = incFilename(videoIn->ImageFName, 
         global->imgFPath,
         global->image_inc);
-    //g_mutex_unlock(videoIn->mutex);
 
-    //g_mutex_lock(global->mutex);
     if(!global->no_display)
     {
         g_snprintf(global->imageinc_str,24,_("File num:%d"),global->image_inc);
@@ -201,7 +200,7 @@ DiskSupervisor(gpointer data)
     }
 
     if(global->debug) 
-        g_printf("(%s) %lluK bytes free on a total of %lluK (used: %d %%) treshold=%iK\n", 
+        g_print("(%s) %lluK bytes free on a total of %lluK (used: %d %%) treshold=%iK\n", 
             global->vidFPath[1], (unsigned long long) free_kbytes, 
             (unsigned long long) total_kbytes, percent, free_tresh);
 
@@ -225,9 +224,9 @@ FreeDiskCheck_timer(gpointer data)
     struct GLOBAL *global = all_data->global;
     struct GWIDGET *gwidget = all_data->gwidget;
 
-    g_mutex_lock(videoIn->mutex);
+    __LOCK_MUTEX(__VMUTEX);
         gboolean capVid = videoIn->capVid;
-    g_mutex_unlock(videoIn->mutex);
+    __UNLOCK_MUTEX(__VMUTEX);
 
     if (capVid) 
     {
@@ -235,7 +234,7 @@ FreeDiskCheck_timer(gpointer data)
         {
             g_printerr("Stopping video Capture\n");
             /*stop video capture*/
-            if(global->debug) g_printf("setting video toggle to FALSE\n");
+            if(global->debug) g_print("setting video toggle to FALSE\n");
             if(!global->no_display)
             {
                 gdk_threads_enter();
@@ -283,22 +282,22 @@ check_v4l2_udev_events(gpointer data)
         {
             if (global->debug)
             {
-                g_printf("Got Device event\n");
-                g_printf("   Node: %s\n", udev_device_get_devnode(dev));
-                g_printf("   Subsystem: %s\n", udev_device_get_subsystem(dev));
-                g_printf("   Devtype: %s\n", udev_device_get_devtype(dev));
+                g_print("Got Device event\n");
+                g_print("   Node: %s\n", udev_device_get_devnode(dev));
+                g_print("   Subsystem: %s\n", udev_device_get_subsystem(dev));
+                g_print("   Devtype: %s\n", udev_device_get_devtype(dev));
 
-                g_printf("   Action: %s\n",udev_device_get_action(dev));
+                g_print("   Action: %s\n",udev_device_get_action(dev));
             }
             
             /*update device list*/
-            g_signal_handlers_block_by_func(GTK_COMBO_BOX(gwidget->Devices), 
+            g_signal_handlers_block_by_func(GTK_COMBO_BOX_TEXT(gwidget->Devices), 
                 G_CALLBACK (Devices_changed), all_data);
                 
             /* clear out the old device list... */
             if(videoIn->listDevices != NULL) freeDevices(videoIn->listDevices);
             
-            GtkListStore *store = GTK_LIST_STORE(gtk_combo_box_get_model (GTK_COMBO_BOX (gwidget->Devices)));
+            GtkListStore *store = GTK_LIST_STORE(gtk_combo_box_get_model (GTK_COMBO_BOX(gwidget->Devices)));
             gtk_list_store_clear(store);
             
             /*create new device list*/
@@ -307,7 +306,7 @@ check_v4l2_udev_events(gpointer data)
             if (videoIn->listDevices->num_devices < 1)
             {
                 //use current
-                gtk_combo_box_append_text(GTK_COMBO_BOX(gwidget->Devices),
+                gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gwidget->Devices),
                     videoIn->videodevice);
                 gtk_combo_box_set_active(GTK_COMBO_BOX(gwidget->Devices),0);
             }
@@ -316,13 +315,13 @@ check_v4l2_udev_events(gpointer data)
                 int i=0;
                 for(i=0;i<(videoIn->listDevices->num_devices);i++)
                 {
-                    gtk_combo_box_append_text(GTK_COMBO_BOX(gwidget->Devices),
+                    gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(gwidget->Devices),
                         videoIn->listDevices->listVidDevices[i].name);
                     if(videoIn->listDevices->listVidDevices[i].current)
                         gtk_combo_box_set_active(GTK_COMBO_BOX(gwidget->Devices),i);
                 }
             }
-            g_signal_handlers_unblock_by_func(GTK_COMBO_BOX(gwidget->Devices), 
+            g_signal_handlers_unblock_by_func(GTK_COMBO_BOX_TEXT(gwidget->Devices), 
                 G_CALLBACK (Devices_changed), all_data);
             
             udev_device_unref(dev);
