@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #                                                                               #
@@ -532,20 +532,9 @@ static void update_ctrl_list_flags(Control *control_list)
 {
     Control *current = control_list;
     Control *next = current->next;
-    int done = 0;
     
-    while(!done)
-    {
+    for(; next != NULL; current = next, next = current->next)
         update_ctrl_flags(control_list, current->control.id);
-        
-        if(next == NULL)
-            done = 1;
-        else
-        {
-            current = next;
-            next = current->next;
-        }
-    }
 }
 
 /*
@@ -567,8 +556,7 @@ static void update_widget_state(Control *control_list, void *all_data)
 {
     Control *current = control_list;
     Control *next = current->next;
-    int done = 0;
-    while(!done)
+    for(; next != NULL; current = next, next = current->next)
     {
         if(all_data && current->widget)
         {
@@ -609,7 +597,7 @@ static void update_widget_state(Control *control_list, void *all_data)
                 case V4L2_CTRL_TYPE_MENU:
                 {
                     //disable widget signals
-                    g_signal_handlers_block_by_func(GTK_COMBO_BOX(current->widget), 
+                    g_signal_handlers_block_by_func(GTK_COMBO_BOX_TEXT(current->widget), 
                         G_CALLBACK (combo_changed), all_data);
                     //get new index
                     int j = 0;
@@ -622,7 +610,7 @@ static void update_widget_state(Control *control_list, void *all_data)
                     
                     gtk_combo_box_set_active(GTK_COMBO_BOX(current->widget), def);
                     //enable widget signals    
-                    g_signal_handlers_unblock_by_func(GTK_COMBO_BOX(current->widget), 
+                    g_signal_handlers_unblock_by_func(GTK_COMBO_BOX_TEXT(current->widget), 
                         G_CALLBACK (combo_changed), all_data);
                     break;
                 }
@@ -649,14 +637,6 @@ static void update_widget_state(Control *control_list, void *all_data)
             if(current->spinbutton)
                 gtk_widget_set_sensitive (current->spinbutton, TRUE);
         }
-        
-        if(next == NULL)
-            done = 1;
-        else
-        {
-            current = next;
-            next = current->next;
-        }
     }
 }
 
@@ -670,17 +650,17 @@ void create_control_widgets(Control *control_list, void *all_data, int control_o
     struct vdIn *videoIn = data->videoIn;
     Control *current = control_list;
     Control *next = current->next;
-    int done = 0;
     int i = 0;
     
-    while(!done)
+    for(; next != NULL; current = next, next = current->next)
     {
+    	get_ctrl(videoIn->fd, control_list, current->control.id, all_data);
         if (verbose) 
         {
-            g_printf("control[%d]: 0x%x",i ,current->control.id);
-            g_printf ("  %s, %d:%d:%d, default %d\n", current->control.name,
+            g_print("control[%d]: 0x%x",i ,current->control.id);
+            g_print ("  %s, %d:%d:%d, default %d , current %d\n", current->control.name,
                 current->control.minimum, current->control.maximum, current->control.step,
-                current->control.default_value);
+                current->control.default_value, current->value);
         }
         
         if(!current->control.step) current->control.step = 1;
@@ -723,7 +703,7 @@ void create_control_widgets(Control *control_list, void *all_data, int control_o
                         case V4L2_CID_TILT_RELATIVE:
                         {
                             //videoIn->PanTilt++;
-                            current->widget = gtk_hbox_new (TRUE, 1);
+                            current->widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 1);
 
                             GtkWidget *PanTilt1 = NULL;
                             GtkWidget *PanTilt2 = NULL;
@@ -780,50 +760,95 @@ void create_control_widgets(Control *control_list, void *all_data, int control_o
                     
                         case V4L2_CID_LED1_MODE_LOGITECH:
                         {
+                        	char* LEDMenu[4] = {_("Off"),_("On"),_("Blinking"),_("Auto")}; 
                             /*turn it into a menu control*/
-                            current->widget = gtk_combo_box_new_text ();
-                            gtk_combo_box_append_text (
-                                    GTK_COMBO_BOX (current->widget),
-                                    _("Off"));
-                            gtk_combo_box_append_text (
-                                    GTK_COMBO_BOX (current->widget),
-                                    _("On"));
-                            gtk_combo_box_append_text (
-                                    GTK_COMBO_BOX (current->widget),
-                                    _("Blinking"));
-                            gtk_combo_box_append_text (
-                                    GTK_COMBO_BOX (current->widget),
-                                    _("Auto"));
-                            gtk_combo_box_set_active (GTK_COMBO_BOX (current->widget), current->value);
-                            gtk_widget_show (current->widget);
-                             
-                            g_object_set_data (G_OBJECT (current->widget), "control_info", 
-                                GINT_TO_POINTER(current->control.id));
-                            //connect signal
-                            g_signal_connect (GTK_COMBO_BOX(current->widget), "changed",
-                                G_CALLBACK (combo_changed), all_data);
+                            if(!current->menu)
+                    			current->menu = g_new0(struct v4l2_querymenu, 4+1);
+                    		else
+                    			current->menu = g_renew(struct v4l2_querymenu, current->menu, 4+1);
+                   			 
+                   			current->menu[0].id = current->control.id;
+                   			current->menu[0].index = 0;
+                   			current->menu[0].name[0] = 'N'; //just set something here
+                   			current->menu[1].id = current->control.id;
+                   			current->menu[1].index = 1;
+                   			current->menu[1].name[0] = 'O';
+                   			current->menu[2].id = current->control.id;
+                   			current->menu[2].index = 2;
+                   			current->menu[2].name[0] = 'B';
+                   			current->menu[3].id = current->control.id;
+                   			current->menu[3].index = 3;
+                   			current->menu[3].name[0] = 'A';
+                   			current->menu[4].id = current->control.id;
+                   			current->menu[4].index = current->control.maximum+1;
+                   			current->menu[4].name[0] = '\0';
+                   			
+                            int j = 0;
+                        	int def = 0;
+                        	current->widget = gtk_combo_box_text_new ();
+                        	for (j = 0; current->menu[j].index <= current->control.maximum; j++) 
+                        	{
+                        		if (verbose) 
+        	                   		printf("adding menu entry %d: %d, %s\n",j, current->menu[j].index, current->menu[j].name);
+                            	gtk_combo_box_text_append_text (
+                                	GTK_COMBO_BOX_TEXT (current->widget),
+                                	(char *) LEDMenu[j]);
+                            	if(current->value == current->menu[j].index)
+                            		def = j;
+                        	}
+                        
+                        	gtk_combo_box_set_active (GTK_COMBO_BOX(current->widget), def);
+                        	gtk_widget_show (current->widget);
+                         
+                        	g_object_set_data (G_OBJECT (current->widget), "control_info", 
+                            	GINT_TO_POINTER(current->control.id));
+                        	//connect signal
+                       	 	g_signal_connect (GTK_COMBO_BOX_TEXT(current->widget), "changed",
+                            	G_CALLBACK (combo_changed), all_data);
                         };
                         break;
                         
                         case V4L2_CID_RAW_BITS_PER_PIXEL_LOGITECH:
                         {
                             /*turn it into a menu control*/
-                            current->widget = gtk_combo_box_new_text ();
-                            gtk_combo_box_append_text (
-                                    GTK_COMBO_BOX (current->widget),
-                                    _("8 bit"));
-                            gtk_combo_box_append_text (
-                                    GTK_COMBO_BOX (current->widget),
-                                    _("12 bit"));
-                            
-                            gtk_combo_box_set_active (GTK_COMBO_BOX (current->widget), current->value);
-                            gtk_widget_show (current->widget);
-                             
-                            g_object_set_data (G_OBJECT (current->widget), "control_info", 
-                                GINT_TO_POINTER(current->control.id));
-                            //connect signal
-                            g_signal_connect (GTK_COMBO_BOX(current->widget), "changed",
-                                G_CALLBACK (combo_changed), all_data);
+                            char* BITSMenu[2] = {_("8 bit"),_("12 bit")}; 
+                            /*turn it into a menu control*/
+                            if(!current->menu)
+                    			current->menu = g_new0(struct v4l2_querymenu, 2+1);
+                    		else
+                    			current->menu = g_renew(struct v4l2_querymenu, current->menu, 2+1);
+                   			 
+                   			current->menu[0].id = current->control.id;
+                   			current->menu[0].index = 0;
+                   			current->menu[0].name[0] = 'o'; //just set something here
+                   			current->menu[1].id = current->control.id;
+                   			current->menu[1].index = 1;
+                   			current->menu[1].name[0] = 'd';
+                   			current->menu[2].id = current->control.id;
+                   			current->menu[2].index = 2;
+                   			current->menu[2].name[0] = '\0';
+                            int j = 0;
+                        	int def = 0;
+                        	current->widget = gtk_combo_box_text_new ();
+                        	for (j = 0; current->menu[j].index <= current->control.maximum; j++) 
+                        	{
+                        		if (verbose) 
+        	                   		printf("adding menu entry %d: %d, %s\n",j, current->menu[j].index, current->menu[j].name);
+                            	gtk_combo_box_text_append_text (
+                                	GTK_COMBO_BOX_TEXT (current->widget),
+                                	(char *) BITSMenu[j]);
+                            	if(current->value == current->menu[j].index)
+                            		def = j;
+                        	}
+                        
+                        	gtk_combo_box_set_active (GTK_COMBO_BOX(current->widget), def);
+                        	gtk_widget_show (current->widget);
+                         
+                        	g_object_set_data (G_OBJECT (current->widget), "control_info", 
+                            	GINT_TO_POINTER(current->control.id));
+                        	//connect signal
+                       	 	g_signal_connect (GTK_COMBO_BOX_TEXT(current->widget), "changed",
+                            	G_CALLBACK (combo_changed), all_data);
                         };
                         break;
                     
@@ -832,12 +857,13 @@ void create_control_widgets(Control *control_list, void *all_data, int control_o
                             /* check for valid range */
                             if((current->control.maximum > current->control.minimum) && (current->control.step != 0))
                             {
-                                current->widget = gtk_hscale_new_with_range (
+                                current->widget = gtk_scale_new_with_range (
+                                	GTK_ORIENTATION_HORIZONTAL,
                                     current->control.minimum,
                                     current->control.maximum,
                                     current->control.step);
                                 gtk_scale_set_draw_value (GTK_SCALE (current->widget), FALSE);
-                                GTK_RANGE (current->widget)->round_digits = 0;
+                                gtk_range_set_round_digits(GTK_RANGE (current->widget), 0);
                                 gtk_widget_show (current->widget);
                             
                                 current->spinbutton = gtk_spin_button_new_with_range(
@@ -877,25 +903,25 @@ void create_control_widgets(Control *control_list, void *all_data, int control_o
                     {
                         int j = 0;
                         int def = 0;
-                        current->widget = gtk_combo_box_new_text ();
+                        current->widget = gtk_combo_box_text_new ();
                         for (j = 0; current->menu[j].index <= current->control.maximum; j++) 
                         {
                         	if (verbose) 
         	                   	printf("adding menu entry %d: %d, %s\n",j, current->menu[j].index, current->menu[j].name);
-                            gtk_combo_box_append_text (
-                                GTK_COMBO_BOX (current->widget),
+                            gtk_combo_box_text_append_text (
+                                GTK_COMBO_BOX_TEXT (current->widget),
                                 (char *) current->menu[j].name);
                             if(current->value == current->menu[j].index)
                             	def = j;
                         }
                         
-                        gtk_combo_box_set_active (GTK_COMBO_BOX (current->widget), def);
+                        gtk_combo_box_set_active (GTK_COMBO_BOX(current->widget), def);
                         gtk_widget_show (current->widget);
                          
                         g_object_set_data (G_OBJECT (current->widget), "control_info", 
                             GINT_TO_POINTER(current->control.id));
                         //connect signal
-                        g_signal_connect (GTK_COMBO_BOX(current->widget), "changed",
+                        g_signal_connect (GTK_COMBO_BOX_TEXT(current->widget), "changed",
                             G_CALLBACK (combo_changed), all_data);
                     }
                 }
@@ -906,21 +932,21 @@ void create_control_widgets(Control *control_list, void *all_data, int control_o
                     if(current->control.id ==V4L2_CID_DISABLE_PROCESSING_LOGITECH)
                     {       
                         //a little hack :D we use the spin widget as a combo
-                        current->spinbutton = gtk_combo_box_new_text ();
-			            gtk_combo_box_append_text(GTK_COMBO_BOX(current->spinbutton),
+                        current->spinbutton = gtk_combo_box_text_new ();
+			            gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(current->spinbutton),
 			                "GBGB... | RGRG...");
-			            gtk_combo_box_append_text(GTK_COMBO_BOX(current->spinbutton),
+			            gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(current->spinbutton),
 			                "GRGR... | BGBG...");
-			            gtk_combo_box_append_text(GTK_COMBO_BOX(current->spinbutton),
+			            gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(current->spinbutton),
 			                "BGBG... | GRGR...");
-			            gtk_combo_box_append_text(GTK_COMBO_BOX(current->spinbutton),
+			            gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(current->spinbutton),
 			                "RGRG... | GBGB...");
 			        
 			            gtk_combo_box_set_active(GTK_COMBO_BOX(current->spinbutton), 0);
 
 			            gtk_widget_show (current->spinbutton);
 			            
-			            g_signal_connect (GTK_COMBO_BOX (current->spinbutton), "changed",
+			            g_signal_connect (GTK_COMBO_BOX_TEXT (current->spinbutton), "changed",
 				            G_CALLBACK (pix_ord_changed), all_data);
 				        
 				        videoIn->isbayer = (current->value ? TRUE : FALSE);
@@ -943,16 +969,7 @@ void create_control_widgets(Control *control_list, void *all_data, int control_o
                 printf("control type: 0x%08x not supported\n", current->control.type);
                 break;
         }
-
-        if(next == NULL)
-            done = 1;
-        else
-        {
-            current = next;
-            next = current->next;
-        }
     }
-    
     update_widget_state(control_list, all_data);
  }
 
@@ -964,14 +981,10 @@ Control *get_ctrl_by_id(Control *control_list, int id)
 {
     Control *current = control_list;
     Control *next = current->next;
-    while (next != NULL)
+    for(; next != NULL; current = next, next = current->next)
     {
         if(current->control.id == id)
-        {
             return (current);
-        }
-        current = next;
-        next = current->next;
     }
     if(current->control.id == id)
         return (current);
@@ -991,12 +1004,11 @@ void get_ctrl_values (int hdevice, Control *control_list, int num_controls, void
     Control *next = current->next;
     int count = 0;
     int i = 0;
-    int done = 0;
     
-    while(!done)
+    for(; next != NULL; current = next, next = current->next)
     {   
         if(current->control.flags & V4L2_CTRL_FLAG_WRITE_ONLY)
-            goto next_control;
+             continue;
             
         clist[count].id = current->control.id;
 #ifndef DISABLE_STRING_CONTROLS 
@@ -1080,16 +1092,6 @@ void get_ctrl_values (int hdevice, Control *control_list, int num_controls, void
             }
             
             count = 0;
-            
-            if(next == NULL)
-                done = 1;
-        }
-        
-next_control:
-        if(!done)
-        {
-            current = next;
-            next = current->next;
         }
     }
     
@@ -1186,12 +1188,11 @@ void set_ctrl_values (int hdevice, Control *control_list, int num_controls)
     Control *next = current->next;
     int count = 0;
     int i = 0;
-    int done = 0;
     
-    while(!done)
+    for(; next != NULL; current = next, next = current->next)
     {
         if(current->control.flags & V4L2_CTRL_FLAG_READ_ONLY)
-            goto next_control;
+            continue;
             
         clist[count].id = current->control.id;
         switch (current->control.type)
@@ -1264,21 +1265,8 @@ void set_ctrl_values (int hdevice, Control *control_list, int num_controls)
                         }
                     }
                 }
-            }
-            
-            
-            
-            count = 0;
-            
-            if(next == NULL)
-                done = 1;
-        }
-
-next_control:
-        if(!done)
-        {
-            current = next;
-            next = current->next;   
+            } 
+            count = 0;  
         }
     }
     
@@ -1293,9 +1281,8 @@ void set_default_values(int hdevice, Control *control_list, int num_controls, vo
 {
     Control *current = control_list;
     Control *next = current->next;
-    int done = 0;
     
-    while(!done)
+    for(; next != NULL; current = next, next = current->next)
     {
         if(current->control.flags & V4L2_CTRL_FLAG_READ_ONLY)
         {
@@ -1324,19 +1311,10 @@ void set_default_values(int hdevice, Control *control_list, int num_controls, vo
                 current->value = current->control.default_value;
                 break;
         }
-        
-        if(next == NULL)
-            done = 1;
-        else
-        {
-            current = next;
-            next = current->next;
-        }
     }
     
     set_ctrl_values (hdevice, control_list, num_controls);
     get_ctrl_values (hdevice, control_list, num_controls, all_data);
-    
 }
 
 /*
