@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #                                                                               #
@@ -48,6 +48,8 @@
 #include "colorspaces.h"
 #include "ms_time.h"
 
+#define __VMUTEX &videoIn->mutex
+
 /* needed only for language files (not used)*/
 
 // V4L2 control strings
@@ -182,7 +184,7 @@ static int check_videoIn(struct vdIn *vd, int *width, int *height)
 			return VDIN_READ_ERR;
 		}
 	}
-	g_printf("Init. %s (location: %s)\n", vd->cap.card, vd->cap.bus_info);
+	g_print("Init. %s (location: %s)\n", vd->cap.card, vd->cap.bus_info);
 	
 	vd->listFormats = enum_frame_formats( width, height, vd->fd);
 	
@@ -401,14 +403,14 @@ int get_jpegcomp(struct vdIn *vd)
 	int ret = xioctl(vd->fd, VIDIOC_G_JPEGCOMP, &vd->jpgcomp);
 	if(!ret)
 	{
-		g_printf("VIDIOC_G_COMP:\n");
-		g_printf("    quality:      %i\n", vd->jpgcomp.quality);
-		g_printf("    APPn:         %i\n", vd->jpgcomp.APPn);
-		g_printf("    APP_len:      %i\n", vd->jpgcomp.APP_len);
-		g_printf("    APP_data:     %s\n", vd->jpgcomp.APP_data);
-		g_printf("    COM_len:      %i\n", vd->jpgcomp.COM_len);
-		g_printf("    COM_data:     %s\n", vd->jpgcomp.COM_data);
-		g_printf("    jpeg_markers: 0x%x\n", vd->jpgcomp.jpeg_markers);
+		g_print("VIDIOC_G_COMP:\n");
+		g_print("    quality:      %i\n", vd->jpgcomp.quality);
+		g_print("    APPn:         %i\n", vd->jpgcomp.APPn);
+		g_print("    APP_len:      %i\n", vd->jpgcomp.APP_len);
+		g_print("    APP_data:     %s\n", vd->jpgcomp.APP_data);
+		g_print("    COM_len:      %i\n", vd->jpgcomp.COM_len);
+		g_print("    COM_data:     %s\n", vd->jpgcomp.COM_data);
+		g_print("    jpeg_markers: 0x%x\n", vd->jpgcomp.jpeg_markers);
 	}
 	else
 	{
@@ -416,7 +418,7 @@ int get_jpegcomp(struct vdIn *vd)
 		if(errno == EINVAL)
 		{
 			vd->jpgcomp.quality = -1; //not supported
-			g_printf("   compression control not supported\n");
+			g_print("   compression control not supported\n");
 		}
 	}
 
@@ -438,7 +440,7 @@ int set_jpegcomp(struct vdIn *vd)
 		if(errno == EINVAL)
 		{
 			vd->jpgcomp.quality = -1; //not supported
-			g_printf("   compression control not supported\n");
+			g_print("   compression control not supported\n");
 		}
 	}
 
@@ -456,7 +458,7 @@ static int init_v4l2(struct vdIn *vd, int *format, int *width, int *height, int
 	int ret = 0;
 	
 	// make sure we set a valid format
-	g_printf("checking format: %i\n", *format);
+	g_print("checking format: %i\n", *format);
 	if ((ret=check_SupPixFormat(*format)) < 0)
 	{
 		// not available - Fail so we can check other formats (don't bother trying it)
@@ -650,8 +652,11 @@ static int videoIn_frame_alloca(struct vdIn *vd, int format, int width, int heig
 		default:
 			g_printerr("(v4l2uvc.c) should never arrive (1)- exit fatal !!\n");
 			ret = VDIN_UNKNOWN_ERR;
-			goto error;
-			break;
+			g_free(vd->framebuffer);
+			vd->framebuffer = NULL;
+			g_free(vd->tmpbuffer);
+			vd->tmpbuffer = NULL;
+			return (ret);
 	}
 	
 	if ((!vd->framebuffer) || (framebuf_size <=0)) 
@@ -659,7 +664,11 @@ static int videoIn_frame_alloca(struct vdIn *vd, int format, int width, int heig
 			g_printerr("couldn't calloc %lu bytes of memory for frame buffer\n",
 				(unsigned long) framebuf_size);
 			ret = VDIN_FBALLOC_ERR;
-			goto error;
+			g_free(vd->framebuffer);
+			vd->framebuffer = NULL;
+			g_free(vd->tmpbuffer);
+			vd->tmpbuffer = NULL;
+			return (ret);
 		} 
 		else
 		{
@@ -674,12 +683,35 @@ static int videoIn_frame_alloca(struct vdIn *vd, int format, int width, int heig
 				}
 		}
 	return (ret);
-error:
-	g_free(vd->framebuffer);
-	vd->framebuffer = NULL;
-	g_free(vd->tmpbuffer);
-	vd->tmpbuffer = NULL;
-	return (ret);
+}
+
+/* cleans VdIn struct and allocations
+ * args:
+ * pointer to initiated vdIn struct
+ *
+ * returns: void
+*/
+void clear_v4l2(struct vdIn *videoIn)
+{
+	v4l2_close(videoIn->fd);
+	videoIn->fd=0;
+	g_free(videoIn->videodevice);
+	g_free(videoIn->VidFName);
+	g_free(videoIn->ImageFName);
+	videoIn->videodevice = NULL;
+	videoIn->VidFName = NULL;
+	videoIn->ImageFName = NULL;
+
+	if(videoIn->cap_meth == IO_READ)
+	{
+		g_print("cleaning read buffer\n");
+		if((videoIn->buf.length > 0) && videoIn->mem[0])
+		{
+			g_free(videoIn->mem[0]);
+			videoIn->mem[0] = NULL;
+		}
+	}
+	__CLOSE_MUTEX( __VMUTEX );
 }
 
 /* Init VdIn struct with default and/or global values
@@ -689,115 +721,117 @@ error:
  *
  * returns: error code ( 0 - VDIN_OK)
 */
-int init_videoIn(struct vdIn *vd, struct GLOBAL *global)
+int init_videoIn(struct vdIn *videoIn, struct GLOBAL *global)
 {
 	int ret = VDIN_OK;
 	char *device = global->videodevice;
     
     /* Create a udev object */
-    vd->udev = udev_new();
+    videoIn->udev = udev_new();
 
-	vd->mutex = g_mutex_new();
-	if (vd == NULL || device == NULL)
+	__INIT_MUTEX( __VMUTEX );
+	if (videoIn == NULL || device == NULL)
 		return VDIN_ALLOC_ERR;
 	if (global->width == 0 || global->height == 0)
 		return VDIN_RESOL_ERR;
 	if (global->cap_meth < IO_MMAP || global->cap_meth > IO_READ)
 		global->cap_meth = IO_MMAP;		//mmap by default
-	vd->cap_meth = global->cap_meth;
-	if(global->debug) g_printf("capture method = %i\n",vd->cap_meth);
-	vd->videodevice = NULL;
-	vd->videodevice = g_strdup(device);
-	g_printf("video device: %s \n", vd->videodevice);
+	videoIn->cap_meth = global->cap_meth;
+	if(global->debug) g_print("capture method = %i\n",videoIn->cap_meth);
+	videoIn->videodevice = NULL;
+	videoIn->videodevice = g_strdup(device);
+	g_print("video device: %s \n", videoIn->videodevice);
 	
 	//flag to video thread
-	vd->capVid = FALSE;
+	videoIn->capVid = FALSE;
 	//flag from video thread
-	vd->VidCapStop=TRUE;
+	videoIn->VidCapStop=TRUE;
 	
-	vd->VidFName = g_strdup(DEFAULT_AVI_FNAME);
-	vd->signalquit = FALSE;
-	vd->PanTilt=0;
-	vd->isbayer = 0; //bayer mode off
-	vd->pix_order=0; // pix order for bayer mode def: gbgbgb..|rgrgrg..
-	vd->setFPS=0; 
-	vd->capImage=FALSE;
-	vd->cap_raw=0;
+	videoIn->VidFName = g_strdup(DEFAULT_AVI_FNAME);
+	videoIn->signalquit = FALSE;
+	videoIn->PanTilt=0;
+	videoIn->isbayer = 0; //bayer mode off
+	videoIn->pix_order=0; // pix order for bayer mode def: gbgbgb..|rgrgrg..
+	videoIn->setFPS=0; 
+	videoIn->capImage=FALSE;
+	videoIn->cap_raw=0;
 	
-	vd->ImageFName = g_strdup(DEFAULT_IMAGE_FNAME);
+	videoIn->ImageFName = g_strdup(DEFAULT_IMAGE_FNAME);
 	
 	//timestamps not supported by UVC driver
 	//vd->timecode.type = V4L2_TC_TYPE_25FPS;
 	//vd->timecode.flags = V4L2_TC_FLAG_DROPFRAME;
 	
-	vd->available_exp[0]=-1;
-	vd->available_exp[1]=-1;
-	vd->available_exp[2]=-1;
-	vd->available_exp[3]=-1;
+	videoIn->available_exp[0]=-1;
+	videoIn->available_exp[1]=-1;
+	videoIn->available_exp[2]=-1;
+	videoIn->available_exp[3]=-1;
 	
-	vd->tmpbuffer = NULL;
-	vd->framebuffer = NULL;
+	videoIn->tmpbuffer = NULL;
+	videoIn->framebuffer = NULL;
 	
     /*start udev device monitoring*/
     /* Set up a monitor to monitor v4l2 devices */
-    if(vd->udev)
+    if(videoIn->udev)
     {
-        vd->udev_mon = udev_monitor_new_from_netlink(vd->udev, "udev");
-        udev_monitor_filter_add_match_subsystem_devtype(vd->udev_mon, "video4linux", NULL);
-        udev_monitor_enable_receiving(vd->udev_mon);
+        videoIn->udev_mon = udev_monitor_new_from_netlink(videoIn->udev, "udev");
+        udev_monitor_filter_add_match_subsystem_devtype(videoIn->udev_mon, "video4linux", NULL);
+        udev_monitor_enable_receiving(videoIn->udev_mon);
         /* Get the file descriptor (fd) for the monitor */
-        vd->udev_fd = udev_monitor_get_fd(vd->udev_mon);
+        videoIn->udev_fd = udev_monitor_get_fd(videoIn->udev_mon);
     }
 
-    vd->listDevices = enum_devices( vd->videodevice, vd->udev, (int) global->debug);
+    videoIn->listDevices = enum_devices( videoIn->videodevice, videoIn->udev, (int) global->debug);
 	
-	if (vd->listDevices != NULL)
+	if (videoIn->listDevices != NULL)
 	{
-		if(!(vd->listDevices->listVidDevices))
-			g_printerr("unable to detect video devices on your system (%i)\n", vd->listDevices->num_devices);
+		if(!(videoIn->listDevices->listVidDevices))
+			g_printerr("unable to detect video devices on your system (%i)\n", videoIn->listDevices->num_devices);
 	}
 	else
 		g_printerr("Unable to detect devices on your system\n");
 	
-	if (vd->fd <=0 ) //open device
+	if (videoIn->fd <=0 ) //open device
 	{
-		if ((vd->fd = v4l2_open(vd->videodevice, O_RDWR | O_NONBLOCK, 0)) < 0) 
+		if ((videoIn->fd = v4l2_open(videoIn->videodevice, O_RDWR | O_NONBLOCK, 0)) < 0) 
 		{
 			perror("ERROR opening V4L interface");
 			ret = VDIN_DEVICE_ERR;
-			goto error;
+			clear_v4l2(videoIn);
+			return (ret);
 		}
 	}
 	
 	//reset v4l2_format
-	memset(&vd->fmt, 0, sizeof(struct v4l2_format));
+	memset(&videoIn->fmt, 0, sizeof(struct v4l2_format));
 	// populate video capabilities structure array
 	// should only be called after all vdIn struct elements 
 	// have been initialized
-	if((ret = check_videoIn(vd, &global->width, &global->height)) != VDIN_OK)
+	if((ret = check_videoIn(videoIn, &global->width, &global->height)) != VDIN_OK)
 	{
-		goto error;
+		clear_v4l2(videoIn);
+		return (ret);
 	}
 	
 	//add dynamic controls
 	//only for uvc logitech cameras
 	//needs admin rights
-	if(vd->listDevices->num_devices > 0)
+	if(videoIn->listDevices->num_devices > 0)
 	{
-		g_printf("vid:%04x \npid:%04x \ndriver:%s\n",
-			vd->listDevices->listVidDevices[vd->listDevices->current_device].vendor,
-			vd->listDevices->listVidDevices[vd->listDevices->current_device].product,
-			vd->listDevices->listVidDevices[vd->listDevices->current_device].driver);
-		if(g_strcmp0(vd->listDevices->listVidDevices[vd->listDevices->current_device].driver,"uvcvideo") == 0)
+		g_print("vid:%04x \npid:%04x \ndriver:%s\n",
+			videoIn->listDevices->listVidDevices[videoIn->listDevices->current_device].vendor,
+			videoIn->listDevices->listVidDevices[videoIn->listDevices->current_device].product,
+			videoIn->listDevices->listVidDevices[videoIn->listDevices->current_device].driver);
+		if(g_strcmp0(videoIn->listDevices->listVidDevices[videoIn->listDevices->current_device].driver,"uvcvideo") == 0)
 		{
-			if(vd->listDevices->listVidDevices[vd->listDevices->current_device].vendor != 0)
+			if(videoIn->listDevices->listVidDevices[videoIn->listDevices->current_device].vendor != 0)
 			{
 				//check for logitech vid
-				if (vd->listDevices->listVidDevices[vd->listDevices->current_device].vendor == 0x046d)
-					(ret=initDynCtrls(vd->fd));
+				if (videoIn->listDevices->listVidDevices[videoIn->listDevices->current_device].vendor == 0x046d)
+					(ret=initDynCtrls(videoIn->fd));
 				else ret= VDIN_DYNCTRL_ERR;
 			}
-			else (ret=initDynCtrls(vd->fd));
+			else (ret=initDynCtrls(videoIn->fd));
 		}
 		else ret = VDIN_DYNCTRL_ERR;
 		
@@ -808,48 +842,29 @@ int init_videoIn(struct vdIn *vd, struct GLOBAL *global)
 		//added extension controls so now we can exit
 		//set a return code for enabling the correct warning window
 		ret = (ret ? VDIN_DYNCTRL_ERR: VDIN_DYNCTRL_OK);
-		goto error;
+		clear_v4l2(videoIn);
+		return (ret);
 	}
 	else ret = 0; //clean ret code
 	
 	if(!(global->control_only))
 	{
-		if ((ret=init_v4l2(vd, &global->format, &global->width, &global->height, &global->fps, &global->fps_num)) < 0) 
+		if ((ret=init_v4l2(videoIn, &global->format, &global->width, &global->height, &global->fps, &global->fps_num)) < 0) 
 		{
 			g_printerr("Init v4L2 failed !! \n");
-			goto error;
+			clear_v4l2(videoIn);
+			return (ret);
 		}
 		
-		g_printf("fps is set to %i/%i\n", global->fps_num, global->fps);
+		g_print("fps is set to %i/%i\n", global->fps_num, global->fps);
 		/*allocations*/
-		if((ret = videoIn_frame_alloca(vd, global->format, global->width, global->height)) != VDIN_OK)
+		if((ret = videoIn_frame_alloca(videoIn, global->format, global->width, global->height)) != VDIN_OK)
 		{
-			goto error;
+			clear_v4l2(videoIn);
+			return (ret);
 		}
 	}
 	return (ret);
-error:
-	v4l2_close(vd->fd);
-	vd->fd=0;
-	g_free(vd->videodevice);
-	g_free(vd->VidFName);
-	g_free(vd->ImageFName);
-	vd->videodevice = NULL;
-	vd->VidFName = NULL;
-	vd->ImageFName = NULL;
-	
-	if(vd->cap_meth == IO_READ)
-	{
-		g_printf("cleaning read buffer\n");
-		if((vd->buf.length > 0) && vd->mem[0]) 
-		{
-			g_free(vd->mem[0]);
-			vd->mem[0] = NULL;
-		}
-	}
-	g_mutex_free( vd->mutex );
-	vd->mutex = NULL;
-	return ret;
 }
 
 /* decode video stream (frame buffer in yuyv format)
@@ -869,7 +884,7 @@ static int frame_decode(struct vdIn *vd, int format, int width, int height)
 			if(vd->buf.bytesused <= HEADERFRAME1) 
 			{
 				// Prevent crash on empty image
-				g_printf("Ignoring empty buffer ...\n");
+				g_print("Ignoring empty buffer ...\n");
 				return (ret);
 			}
 			memcpy(vd->tmpbuffer, vd->mem[vd->buf.index],vd->buf.bytesused);
@@ -878,7 +893,7 @@ static int frame_decode(struct vdIn *vd, int format, int width, int height)
 			{
 				g_printerr("jpeg decode errors\n");
 				ret = VDIN_DECODE_ERR;
-				goto err;
+				return ret;
 			}
 			break;
 		
@@ -1012,12 +1027,9 @@ static int frame_decode(struct vdIn *vd, int format, int width, int height)
 		default:
 			g_printerr("error grabbing (v4l2uvc.c) unknown format: %i\n", format);
 			ret = VDIN_UNKNOWN_ERR;
-			goto err;
-			break;
+			return ret;
 	}
 	return ret;
-err:
-	return ret;
 }
 
 /* Grabs video frame and decodes it if necessary
@@ -1034,7 +1046,11 @@ int uvcGrab(struct vdIn *vd, int format, int width, int height, int *fps, int *f
 	UINT64 ts = 0;
 	//make sure streaming is on
 	if (!vd->isstreaming)
-		if (video_enable(vd)) goto err;
+		if (video_enable(vd)) 
+		{
+			vd->signalquit = TRUE;
+			return ret;
+		}
 	
 	FD_ZERO(&rdset);
 	FD_SET(vd->fd, &rdset);
@@ -1073,7 +1089,7 @@ int uvcGrab(struct vdIn *vd, int format, int width, int height, int *fps, int *f
 					switch (errno) 
 					{
 						case EAGAIN:
-							g_printf("No data available for read\n");
+							g_print("No data available for read\n");
 							return VDIN_SELETIMEOUT_ERR;
 							break;
 						case EINVAL:
@@ -1163,13 +1179,11 @@ int uvcGrab(struct vdIn *vd, int format, int width, int height, int *fps, int *f
 	
 	if ((ret = frame_decode(vd, format, width, height)) != VDIN_OK)
 	{
-		goto err;
+		vd->signalquit = TRUE;
+		return ret;
 	}
 	
 	return VDIN_OK;
-err:
-	vd->signalquit = TRUE;
-	return ret;
 }
 
 static int close_v4l2_buffers (struct vdIn *vd)
@@ -1218,23 +1232,20 @@ int restart_v4l2(struct vdIn *vd, struct GLOBAL *global)
 	if ((ret=init_v4l2(vd, &global->format, &global->width, &global->height, &global->fps, &global->fps_num)) < 0) 
 	{
 		g_printerr("Init v4L2 failed !! \n");
-		goto error;
+		vd->signalquit = TRUE;
+		return ret;
 	}
 	/*allocations*/
 	if((ret = videoIn_frame_alloca(vd, global->format, global->width, global->height)) != VDIN_OK)
 	{
-		goto error;
+		vd->signalquit = TRUE;
+		return ret;
 	}
 	/*try to start the video stream*/
 	//it's OK if it fails since it is retried in uvcGrab
 	video_enable(vd);
 	
-	return (ret);
-//error: clean up allocs
-error:
-	vd->signalquit = TRUE;
-	return (ret);
-	
+	return (ret);	
 }
 
 /* cleans VdIn struct and allocations
@@ -1243,34 +1254,33 @@ error:
  *
  * returns: void
 */
-void close_v4l2(struct vdIn *vd, gboolean control_only)
+void close_v4l2(struct vdIn *videoIn, gboolean control_only)
 {
-	if (vd->isstreaming) video_disable(vd);
+	if (videoIn->isstreaming) video_disable(videoIn);
 
-    if (vd->udev) udev_unref(vd->udev);
+    if (videoIn->udev) udev_unref(videoIn->udev);
 
-	if(vd->videodevice) g_free(vd->videodevice);
-	if(vd->ImageFName)g_free(vd->ImageFName);
-	if(vd->VidFName)g_free(vd->VidFName);
+	if(videoIn->videodevice) g_free(videoIn->videodevice);
+	if(videoIn->ImageFName)g_free(videoIn->ImageFName);
+	if(videoIn->VidFName)g_free(videoIn->VidFName);
 	// free format allocations
-	if(vd->listFormats) freeFormats(vd->listFormats);
+	if(videoIn->listFormats) freeFormats(videoIn->listFormats);
 	if (!control_only)
 	{
-		close_v4l2_buffers(vd);
+		close_v4l2_buffers(videoIn);
 	}
-	vd->videodevice = NULL;
-	vd->tmpbuffer = NULL;
-	vd->framebuffer = NULL;
-	vd->ImageFName = NULL;
-	vd->VidFName = NULL;
-	if(vd->listDevices != NULL) freeDevices(vd->listDevices);
+	videoIn->videodevice = NULL;
+	videoIn->tmpbuffer = NULL;
+	videoIn->framebuffer = NULL;
+	videoIn->ImageFName = NULL;
+	videoIn->VidFName = NULL;
+	if(videoIn->listDevices != NULL) freeDevices(videoIn->listDevices);
 	// close device descriptor
-	if(vd->fd) v4l2_close(vd->fd);
-	if(vd->mutex) g_mutex_free( vd->mutex );
-	vd->mutex = NULL;
+	if(videoIn->fd) v4l2_close(videoIn->fd);
+	__CLOSE_MUTEX( __VMUTEX );
 	// free struct allocation
-	if(vd) g_free(vd);
-	vd=NULL;
+	if(videoIn) g_free(videoIn);
+	videoIn=NULL;
 }
 
 /* sets video device frame rate
