@@ -1,5 +1,5 @@
 /*******************************************************************************#
-#           guvcview              http://guvcview.berlios.de                    #
+#           guvcview              http://guvcview.sourceforge.net               #
 #                                                                               #
 #           Paulo Assis <pj.assis@gmail.com>                                    #
 #           Nobuhiro Iwamatsu <iwamatsu@nigauri.org>                            #
@@ -46,6 +46,10 @@
 #include "timers.h"
 #include "osd.h"
 
+#define __AMUTEX &pdata->mutex
+#define __VMUTEX &videoIn->mutex
+#define __GMUTEX &global->mutex
+
 static Uint32 SDL_VIDEO_Flags =
         SDL_ANYFORMAT | SDL_RESIZABLE;
         
@@ -83,17 +87,17 @@ static SDL_Overlay * video_init(void *data, SDL_Surface **pscreen)
      
         if (SDL_VideoDriverName(driver, sizeof(driver)) && global->debug) 
         {
-            g_printf("Video driver: %s\n", driver);
+            g_print("Video driver: %s\n", driver);
         }
     
         info = SDL_GetVideoInfo();
 
-        if (info->wm_available && global->debug) g_printf("A window manager is available\n");
+        if (info->wm_available && global->debug) g_print("A window manager is available\n");
 
         if (info->hw_available) 
         {
             if (global->debug) 
-                g_printf("Hardware surfaces are available (%dK video memory)\n", info->video_mem);
+                g_print("Hardware surfaces are available (%dK video memory)\n", info->video_mem);
 
             SDL_VIDEO_Flags |= SDL_HWSURFACE;
             SDL_VIDEO_Flags |= SDL_DOUBLEBUF;
@@ -105,7 +109,7 @@ static SDL_Overlay * video_init(void *data, SDL_Surface **pscreen)
         
         if (info->blit_hw) 
         {
-            if (global->debug) g_printf("Copy blits between hardware surfaces are accelerated\n");
+            if (global->debug) g_print("Copy blits between hardware surfaces are accelerated\n");
 
             SDL_VIDEO_Flags |= SDL_ASYNCBLIT;
         }
@@ -115,12 +119,12 @@ static SDL_Overlay * video_init(void *data, SDL_Surface **pscreen)
     
         if (global->debug) 
         {
-            if (info->blit_hw_CC) g_printf ("Colorkey blits between hardware surfaces are accelerated\n");
-            if (info->blit_hw_A) g_printf("Alpha blits between hardware surfaces are accelerated\n");
-            if (info->blit_sw) g_printf ("Copy blits from software surfaces to hardware surfaces are accelerated\n");
-            if (info->blit_sw_CC) g_printf ("Colorkey blits from software surfaces to hardware surfaces are accelerated\n");
-            if (info->blit_sw_A) g_printf("Alpha blits from software surfaces to hardware surfaces are accelerated\n");
-            if (info->blit_fill) g_printf("Color fills on hardware surfaces are accelerated\n");
+            if (info->blit_hw_CC) g_print ("Colorkey blits between hardware surfaces are accelerated\n");
+            if (info->blit_hw_A) g_print("Alpha blits between hardware surfaces are accelerated\n");
+            if (info->blit_sw) g_print ("Copy blits from software surfaces to hardware surfaces are accelerated\n");
+            if (info->blit_sw_CC) g_print ("Colorkey blits from software surfaces to hardware surfaces are accelerated\n");
+            if (info->blit_sw_A) g_print("Alpha blits from software surfaces to hardware surfaces are accelerated\n");
+            if (info->blit_fill) g_print("Color fills on hardware surfaces are accelerated\n");
         }
 
         SDL_WM_SetCaption(global->WVcaption, NULL); 
@@ -130,8 +134,8 @@ static SDL_Overlay * video_init(void *data, SDL_Surface **pscreen)
     }
     /*------------------------------ SDL init video ---------------------*/
     if(global->debug)  
-        g_printf("(Desktop resolution = %ix%i)\n", global->desktop_w, global->desktop_h);
-    g_printf("Checking video mode %ix%i@32bpp : ", width, height);
+        g_print("(Desktop resolution = %ix%i)\n", global->desktop_w, global->desktop_h);
+    g_print("Checking video mode %ix%i@32bpp : ", width, height);
     int bpp = SDL_VideoModeOK(
         width,
         height,
@@ -140,7 +144,7 @@ static SDL_Overlay * video_init(void *data, SDL_Surface **pscreen)
 
     if(!bpp)
     {
-        g_printf("Not available \n");
+        g_print("Not available \n");
         /*resize video mode*/
         if ((width > global->desktop_w) || (height > global->desktop_h))
         {
@@ -152,13 +156,13 @@ static SDL_Overlay * video_init(void *data, SDL_Surface **pscreen)
             width = 800;
             height = 600;
         }
-        g_printf("Resizing to %ix%i\n", width, height);
+        g_print("Resizing to %ix%i\n", width, height);
 
     }
     else
     {
-        g_printf("OK \n");
-        if ((bpp != 32) && global->debug) g_printf("recomended color depth = %i\n", bpp);
+        g_print("OK \n");
+        if ((bpp != 32) && global->debug) g_print("recomended color depth = %i\n", bpp);
         global->bpp = bpp;
     }
 
@@ -235,7 +239,7 @@ void *main_loop(void *data)
         
         if(overlay == NULL)
         {
-            g_printf("FATAL: Couldn't create yuv overlay - please disable hardware accelaration\n");
+            g_print("FATAL: Couldn't create yuv overlay - please disable hardware accelaration\n");
             signalquit = TRUE; /*exit video thread*/
         }
         else
@@ -251,10 +255,10 @@ void *main_loop(void *data)
     
     while (!signalquit) 
     {
-        g_mutex_lock(videoIn->mutex);
+        __LOCK_MUTEX(__VMUTEX);
             capVid = videoIn->capVid;
             signalquit = videoIn->signalquit;
-        g_mutex_unlock(videoIn->mutex);
+        __UNLOCK_MUTEX(__VMUTEX);
         
         /*-------------------------- Grab Frame ----------------------------------*/
         if (uvcGrab(videoIn, format, width, height, &global->fps, &global->fps_num) < 0) 
@@ -275,9 +279,9 @@ void *main_loop(void *data)
                 {
                     global->Vidstarttime = videoIn->timestamp;
                     /*use current time for audio ts(0) reference (MONOTONIC)*/
-                    g_mutex_lock(pdata->mutex);
+                    __LOCK_MUTEX(__AMUTEX);
                         pdata->ts_ref = ns_time_monotonic();
-                    g_mutex_unlock(pdata->mutex);
+                    __UNLOCK_MUTEX(__AMUTEX);
                     //printf("video ts ref: %llu audio ts_ ref: %llu\n",global->Vidstarttime, pdata->ts_ref);
                     global->v_ts = 0;
                 }
@@ -324,7 +328,7 @@ void *main_loop(void *data)
                     {
                         AFdata->sharpness=getSharpness (videoIn->framebuffer, width, height, 5);
                         if (global->debug) 
-                            g_printf("sharp=%d focus_sharp=%d foc=%d right=%d left=%d ind=%d flag=%d\n",
+                            g_print("sharp=%d focus_sharp=%d foc=%d right=%d left=%d ind=%d flag=%d\n",
                                 AFdata->sharpness,AFdata->focus_sharpness,
                                 AFdata->focus, AFdata->right, AFdata->left, 
                                 AFdata->ind, AFdata->flag);
@@ -344,13 +348,13 @@ void *main_loop(void *data)
                     else 
                     {
                         AFdata->focus_wait--;
-                        if (global->debug) g_printf("Wait Frame: %d\n",AFdata->focus_wait);
+                        if (global->debug) g_print("Wait Frame: %d\n",AFdata->focus_wait);
                     }
                 }
             }
         }
         /*------------------------- Filter Frame ---------------------------------*/
-        g_mutex_lock(global->mutex);
+        __LOCK_MUTEX(__GMUTEX);
         if(global->Frame_Flags>0)
         {
             if((global->Frame_Flags & YUV_PARTICLES)==YUV_PARTICLES)
@@ -372,7 +376,7 @@ void *main_loop(void *data)
                 pieces (videoIn->framebuffer, width, height, 16 );
             
         }
-        g_mutex_unlock(global->mutex);
+        __UNLOCK_MUTEX(__GMUTEX);
         /*-------------------------capture Image----------------------------------*/
         if (videoIn->capImage)
         {
@@ -384,16 +388,16 @@ void *main_loop(void *data)
             int ret = 0;
             if((ret=store_picture(all_data)) < 0)
                 g_printerr("saved image to:%s ...Failed \n",videoIn->ImageFName);
-            else if (!ret && global->debug) g_printf("saved image to:%s ...OK \n",videoIn->ImageFName);
+            else if (!ret && global->debug) g_print("saved image to:%s ...OK \n",videoIn->ImageFName);
             
             videoIn->capImage=FALSE;
         }
         /*---------------------------capture Video---------------------------------*/
         if (capVid && !(global->skip_n))
         {
-            g_mutex_lock(videoIn->mutex);
+            __LOCK_MUTEX(__VMUTEX);
                 if(videoIn->VidCapStop) videoIn->VidCapStop = FALSE;
-            g_mutex_unlock(videoIn->mutex);
+            __UNLOCK_MUTEX(__VMUTEX);
             int res=0;
             /*format and resolution don't change(disabled) while capturing video*/
             if((res=store_video_frame(all_data))<0) g_printerr("WARNING: droped frame (%i)\n",res);
@@ -401,21 +405,21 @@ void *main_loop(void *data)
         } /*video and audio capture have stopped */
         else
         {
-            g_mutex_lock(videoIn->mutex);
+            __LOCK_MUTEX(__VMUTEX);
                 if(!(videoIn->VidCapStop)) videoIn->VidCapStop=TRUE;
-            g_mutex_unlock(videoIn->mutex);
+            __UNLOCK_MUTEX(__VMUTEX);
         }
 
         /* decrease skip frame count */
         if (global->skip_n > 0)
         {
-            if (global->debug && capVid) g_printf("skiping frame %d...\n", global->skip_n);
+            if (global->debug && capVid) g_print("skiping frame %d...\n", global->skip_n);
             global->skip_n--;
         }
 
-        g_mutex_lock( pdata->mutex );
+        __LOCK_MUTEX( __AMUTEX );
             if (global->Sound_enable && capVid) pdata->skip_n = global->skip_n;
-        g_mutex_unlock( pdata->mutex );
+        __UNLOCK_MUTEX( __AMUTEX );
         
         /*------------------------- Display Frame --------------------------------*/
         if(!global->no_display)
@@ -469,7 +473,14 @@ void *main_loop(void *data)
                     {
                         case 220: /*webcam button*/
                             gdk_threads_enter();
-                            gtk_button_clicked (GTK_BUTTON(gwidget->CapImageButt));
+                           	if (all_data->global->default_action == 0) 
+                           	{
+                           		gtk_button_clicked (GTK_BUTTON(gwidget->CapImageButt));
+                           	} 
+							else 
+							{
+                            	gtk_toggle_button_toggled (GTK_TOGGLE_BUTTON(gwidget->CapVidButt));
+                            }
                             gdk_threads_leave();
                             break;
                     }
@@ -478,7 +489,7 @@ void *main_loop(void *data)
                         case SDLK_q:
                             //shutDown
                             g_timeout_add(200, shutd_timer, all_data);
-                            g_printf("q pressed - Quiting...\n");
+                            g_print("q pressed - Quiting...\n");
                             break;
                         case SDLK_SPACE:
                         {
@@ -500,6 +511,11 @@ void *main_loop(void *data)
                     drect.w = event.resize.w;
                     drect.h = event.resize.h;
                 }
+                if(event.type==SDL_QUIT)
+                {
+                    //shutDown
+                    g_timeout_add(200, shutd_timer, all_data);
+                }
             }
         }
         /* if set make the thread sleep - default no sleep (full throttle)*/
@@ -510,13 +526,13 @@ void *main_loop(void *data)
         /*------------------------------------------*/
         if (global->change_res)
         {
-            g_printf("setting new resolution (%d x %d)\n", global->width, global->height);
+            g_print("setting new resolution (%d x %d)\n", global->width, global->height);
             /*clean up */
             
             if(particles) g_free(particles);
             particles = NULL;
             
-            if (global->debug) g_printf("cleaning buffer allocations\n");
+            if (global->debug) g_print("cleaning buffer allocations\n");
             fflush(NULL);//flush all output buffers 
             
             if(!global->no_display)
@@ -536,12 +552,12 @@ void *main_loop(void *data)
                 overlay = video_init(data, &(pscreen));
                 if(overlay == NULL)
                 {
-                    g_printf("FATAL: Couldn't create yuv overlay - please disable hardware accelaration\n");
+                    g_print("FATAL: Couldn't create yuv overlay - please disable hardware accelaration\n");
                     signalquit = TRUE; /*exit video thread*/
                 }
                 else
                 {
-                    if (global->debug) g_printf("yuv overlay created (%ix%i).\n", overlay->w, overlay->h);
+                    if (global->debug) g_print("yuv overlay created (%ix%i).\n", overlay->w, overlay->h);
                     p = (unsigned char *) overlay->pixels[0];
         
                     drect.x = 0;
@@ -557,35 +573,35 @@ void *main_loop(void *data)
 
     }/*loop end*/
 
-    g_mutex_lock(videoIn->mutex);
+    __LOCK_MUTEX(__VMUTEX);
         capVid = videoIn->capVid;
-    g_mutex_unlock(videoIn->mutex);
+    __UNLOCK_MUTEX(__VMUTEX);
     /*check if thread exited while in Video capture mode*/
     if (capVid) 
     {
         /*stop capture*/
-        if (global->debug) g_printf("stoping Video capture\n");
+        if (global->debug) g_print("stoping Video capture\n");
         //global->Vidstoptime = ns_time_monotonic(); /*this is set in IO thread*/
         videoIn->VidCapStop=TRUE;
         capVid = FALSE;
-        g_mutex_lock(videoIn->mutex);
+        __LOCK_MUTEX(__VMUTEX);
             videoIn->capVid = capVid;
-        g_mutex_unlock(videoIn->mutex);
-        g_mutex_lock(pdata->mutex);
+        __UNLOCK_MUTEX(__VMUTEX);
+        __LOCK_MUTEX(__AMUTEX);
             pdata->capVid = capVid;
-        g_mutex_unlock(pdata->mutex);
+        __UNLOCK_MUTEX(__AMUTEX);
         /*join IO thread*/
-        if (global->debug) g_printf("Shuting Down IO Thread\n");
-        g_thread_join( all_data->IO_thread );
-        if (global->debug) g_printf("IO Thread finished\n");
+        if (global->debug) g_print("Shuting Down IO Thread\n");
+        __THREAD_JOIN( all_data->IO_thread );
+        if (global->debug) g_print("IO Thread finished\n");
     }
     
-    if (global->debug) g_printf("Thread terminated...\n");
+    if (global->debug) g_print("Thread terminated...\n");
     p = NULL;
     if(particles) g_free(particles);
     particles=NULL;
 
-    if (global->debug) g_printf("cleaning Thread allocations: 100%%\n");
+    if (global->debug) g_print("cleaning Thread allocations: 100%%\n");
     fflush(NULL);//flush all output buffers 
     
     if(!global->no_display)
@@ -597,7 +613,7 @@ void *main_loop(void *data)
         SDL_Quit();
     }
 	
-    if (global->debug) g_printf("Video thread completed\n");
+    if (global->debug) g_print("Video thread completed\n");
     
     global = NULL;
     AFdata = NULL;
